@@ -117,7 +117,7 @@ Binding *ParseBinding(Display *dpy, Binding **pblist, char *tline,
     {
       /*
        * Don't let a 0 keycode go through, since that means AnyKey to the
-       * XGrabKey call in GrabKeys().
+       * XGrabKey call.
        */
       keysym = XStringToKeysym(key);
       if (keysym == NoSymbol)
@@ -233,9 +233,9 @@ static void activate_binding(Binding *binding, BindingType type)
   /* grab keys immediately */
   for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
     {
-      if (binding->Context & (C_WINDOW|C_TITLE|C_RALL|C_LALL|C_SIDEBAR|C_ROOT))
+      if (binding->Context & (C_WINDOW|C_TITLE|C_RALL|C_LALL|C_SIDEBAR))
 	GrabWindowKey(dpy, t->frame, binding,
-		      C_WINDOW|C_TITLE|C_RALL|C_LALL|C_SIDEBAR|C_ROOT,
+		      C_WINDOW|C_TITLE|C_RALL|C_LALL|C_SIDEBAR,
 		      GetUnusedModifiers(), True);
       if (binding->Context & C_ICON)
 	{
