@@ -24,6 +24,9 @@ Binding *ParseBinding(Display *dpy, Binding ** pblist, char *tline,
 		      int *nr_right_buttons, unsigned char *buttons_grabbed);
 void key_binding(F_CMD_ARGS);
 void mouse_binding(F_CMD_ARGS);
+#ifdef HAVE_STROKE
+void stroke_binding(F_CMD_ARGS);
+#endif /* HAVE_STROKE */
 unsigned int MaskUsedModifiers(unsigned int in_modifiers);
 unsigned int GetUnusedModifiers(void);
 void ignore_modifiers(F_CMD_ARGS);
