@@ -40,6 +40,7 @@
 #include "misc.h"
 #include "Module.h"
 #include "borders.h"
+#include "module_interface.h"
 
 #ifdef SHAPE
 #include <X11/extensions/shape.h>
@@ -185,41 +186,25 @@ static void DrawButton(FvwmWindow *t, Window win, int w, int h,
 #endif /* PIXMAP_BUTTONS */
 
 #ifdef GRADIENT_BUTTONS
-    case HGradButton:
-    case VGradButton:
+    case GradientButton:
     {
-      XRectangle bounds;
-      bounds.x = bounds.y = 0;
-      bounds.width = w;
-      bounds.height = h;
+      unsigned int g_width;
+      unsigned int g_height;
+
       flush_expose(win);
 
 #ifdef PIXMAP_BUTTONS
       XSetClipMask(dpy, Scr.TransMaskGC, None);
 #endif
-      if (type == HGradButton) {
-	register int i = 0, dw = bounds.width
-	  / bf->u.grad.npixels + 1;
-	while (i < bf->u.grad.npixels)
-	  {
-	    unsigned short x = i * bounds.width / bf->u.grad.npixels;
-	    XSetForeground(dpy, Scr.TransMaskGC, bf->u.grad.pixels[ i++ ]);
-	    XFillRectangle(dpy, win, Scr.TransMaskGC,
-			   bounds.x + x, bounds.y,
-			   dw, bounds.height);
-	  }
-      } else {
-	register int i = 0, dh = bounds.height
-	  / bf->u.grad.npixels + 1;
-	while (i < bf->u.grad.npixels)
-	  {
-	    unsigned short y = i * bounds.height / bf->u.grad.npixels;
-	    XSetForeground(dpy, Scr.TransMaskGC, bf->u.grad.pixels[ i++ ]);
-	    XFillRectangle(dpy, win, Scr.TransMaskGC,
-			   bounds.x, bounds.y + y,
-			   bounds.width, dh);
-	  }
-      }
+
+      /* find out the size the pixmap should be */
+      CalculateGradientDimensions(
+	dpy, win, bf->u.grad.npixels, bf->u.grad.gradient_type,
+	&g_width, &g_height);
+      /* draw the gradient directly into the window */
+      CreateGradientPixmap(
+	dpy, win, Scr.TransMaskGC, bf->u.grad.gradient_type, g_width, g_height,
+	bf->u.grad.npixels, bf->u.grad.pixels, win, 0, 0, w, h);
     }
     break;
 #endif /* GRADIENT_BUTTONS */
@@ -623,7 +608,8 @@ void RedrawBorder (FvwmWindow *t, Bool onoroff,Bool force,Bool Mapped,
       else
       {
 #if defined(PIXMAP_BUTTONS) && defined(BORDERSTYLE)
-	XSetWindowBackgroundPixmap(dpy,t->frame,TexturePixmap);
+	if (TexturePixmap != None)
+	  XSetWindowBackgroundPixmap(dpy,t->frame,TexturePixmap);
 #endif
         XClearWindow(dpy,t->frame);
       }
@@ -964,12 +950,12 @@ void SetTitleBar (FvwmWindow *t,Bool onoroff, Bool NewTitle)
   }
   tb_style = GetDecor(t,titlebar.state[title_state].style);
   if (tb_flags & HOffCenter) {
-      if (tb_flags & HRight)
-	  hor_off = t->title_g.width - w - 10;
-      else
-	  hor_off = 10;
+    if (tb_flags & HRight)
+      hor_off = t->title_g.width - w - 10;
+    else
+      hor_off = 10;
   } else
-      hor_off = (t->title_g.width - w) / 2;
+    hor_off = (t->title_g.width - w) / 2;
 
   NewFontAndColor(GetDecor(t,WindowFont.font->fid),Forecolor, BackColor);
 
@@ -1386,25 +1372,31 @@ void SetShape(FvwmWindow *tmp_win, int w)
 #ifdef SHAPE
   if (ShapesSupported)
   {
-    XRectangle rect;
-
-    XShapeCombineShape (dpy, tmp_win->frame, ShapeBounding,
-                        tmp_win->boundary_width,
-                        tmp_win->title_g.height+tmp_win->boundary_width,
-                        tmp_win->w,
-                        ShapeBounding, ShapeSet);
-    if (tmp_win->title_w)
+    if (tmp_win->wShaped)
     {
-      /* windows w/ titles */
-      rect.x = tmp_win->boundary_width;
-      rect.y = tmp_win->title_g.y;
-      rect.width = w - 2*tmp_win->boundary_width;
-      rect.height = tmp_win->title_g.height;
+      XRectangle rect;
+
+      XShapeCombineShape (dpy, tmp_win->frame, ShapeBounding,
+			  tmp_win->boundary_width,
+			  tmp_win->title_g.height+tmp_win->boundary_width,
+			  tmp_win->w,
+			  ShapeBounding, ShapeSet);
+      if (tmp_win->title_w)
+	{
+	  /* windows w/ titles */
+	  rect.x = tmp_win->boundary_width;
+	  rect.y = tmp_win->title_g.y;
+	  rect.width = w - 2*tmp_win->boundary_width;
+	  rect.height = tmp_win->title_g.height;
 
 
-      XShapeCombineRectangles(dpy,tmp_win->frame,ShapeBounding,
-                              0,0,&rect,1,ShapeUnion,Unsorted);
+	  XShapeCombineRectangles(dpy,tmp_win->frame,ShapeBounding,
+				  0,0,&rect,1,ShapeUnion,Unsorted);
+	}
     }
+    else
+      XShapeCombineMask (dpy, tmp_win->frame, ShapeBounding,
+			 0, 0, None, ShapeSet);
   }
 #endif
 }
