@@ -150,7 +150,7 @@ void InstallWindowColormaps (FvwmWindow *tmp)
   Bool ThisWinInstalled = False;
 
 
-  /* If no window, then install root colormap */
+  /* If no window, then install fvwm colormap */
   if(!tmp)
     tmp = &Scr.FvwmRoot;
 
@@ -217,7 +217,7 @@ void InstallWindowColormaps (FvwmWindow *tmp)
  *
  *	   These matching routines provide a mechanism to insure that
  *	   the root colormap(s) is installed during operations like
- *	   rubber banding or menu display that require colors from
+ *	   rubber banding that require colors from
  *	   that colormap.  Calls may be nested arbitrarily deeply,
  *	   as long as there is one UninstallRootColormap call per
  *	   InstallRootColormap call.
@@ -233,7 +233,7 @@ void InstallRootColormap(void)
   if (Scr.root_pushes == 0)
     {
       tmp = Scr.pushed_window;
-      InstallWindowColormaps(&Scr.FvwmRoot);
+      XInstallColormap(dpy, DefaultColormap(dpy, Scr.screen));
       Scr.pushed_window = tmp;
     }
   Scr.root_pushes++;
@@ -243,7 +243,7 @@ void InstallRootColormap(void)
 /***************************************************************************
  *
  * Unstacks one layer of root colormap pushing
- * If we peel off the last layer, re-install th e application colormap
+ * If we peel off the last layer, re-install the application colormap
  *
  ***************************************************************************/
 void UninstallRootColormap(void)
@@ -259,7 +259,39 @@ void UninstallRootColormap(void)
   return;
 }
 
+/***********************************************************************
+ *
+ *  Procedures:
+ *	<Uni/I>nstallFvwmColormap - Force (un)loads fvwm colormap(s)
+ *	This is used to ensure the fvwm colormap is installed during
+ *	menu operations
+ *
+ ***********************************************************************/
+void InstallFvwmColormap(void)
+{
+  FvwmWindow *tmp;
+  if (Scr.fvwm_pushes == 0)
+    {
+      tmp = Scr.pushed_window;
+      InstallWindowColormaps(&Scr.FvwmRoot);
+      Scr.pushed_window = tmp;
+    }
+  Scr.fvwm_pushes++;
+  return;
+}
 
+void UninstallFvwmColormap(void)
+{
+  if (Scr.fvwm_pushes)
+    Scr.fvwm_pushes--;
+
+  if (!Scr.fvwm_pushes)
+    {
+      InstallWindowColormaps(Scr.pushed_window);
+    }
+
+  return;
+}
 
 /*****************************************************************************
  *
@@ -270,6 +302,13 @@ void UninstallRootColormap(void)
  ****************************************************************************/
 void FetchWmColormapWindows (FvwmWindow *tmp)
 {
+  /* SUBWINDOW COLORMAP PATCH RANDY FRANK, RSI INC., BOULDER, COLORADO, USA */
+   XWindowAttributes      getattribs;
+   XSetWindowAttributes   setattribs;
+   long int               i;
+   unsigned long          valuemask;
+  /* END PATCH*/
+
   if(tmp->cmap_windows != (Window *)NULL)
     XFree((void *)tmp->cmap_windows);
 
@@ -279,4 +318,90 @@ void FetchWmColormapWindows (FvwmWindow *tmp)
       tmp->number_cmap_windows = 0;
       tmp->cmap_windows = NULL;
     }
+/* SUBWINDOW COLORMAP PATCH BY RANDY FRANK, RSI INC., BOULDER, COLORADO, USA
+ * we need to be notified of Enter events into these subwindows
+ * so we can set their colormaps
+ */
+  if (tmp->number_cmap_windows != 0)
+  {
+    for(i=0;i<tmp->number_cmap_windows;i++)
+    {
+      XGetWindowAttributes(dpy, tmp->cmap_windows[i], &getattribs);
+      valuemask = CWEventMask;
+      setattribs.event_mask = getattribs.your_event_mask | EnterWindowMask
+                | LeaveWindowMask;
+      XChangeWindowAttributes(dpy,tmp->cmap_windows[i],valuemask,&setattribs);
+    }
+  }
+  return;
+  /* END PATCH */
 }
+
+/* SUBWINDOW COLORMAP PATCH BY RANDY FRANK, RSI INC., BOULDER, COLORADO, USA*/
+/*****************************************************************************
+ *
+ * Looks through the window list for any matching COLORMAP_WINDOWS
+ *   windows and installs the colormap if one exists.
+ *
+ ****************************************************************************/
+void EnterSubWindowColormap(Window win)
+{
+  FvwmWindow         *t;
+  long int            i;
+  XWindowAttributes   attribs;
+
+  for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
+  {
+    if (t->number_cmap_windows != 0)
+    {
+      for(i=0;i<t->number_cmap_windows;i++)
+      {
+	if (t->cmap_windows[i] == win)
+	{
+	  XGetWindowAttributes(dpy,win,&attribs);
+	  XInstallColormap(dpy,attribs.colormap);
+	  last_cmap = attribs.colormap;
+	  return;
+	}
+      }
+    }
+  }
+  return;
+}
+
+void LeaveSubWindowColormap(Window win)
+{
+  FvwmWindow         *t;
+  long int            i;
+  int               bWinInList,bParentInList;
+
+  for (t = Scr.FvwmRoot.next; t != NULL; t = t->next)
+  {
+    if (t->number_cmap_windows != 0)
+    {
+      bWinInList = 0;
+      bParentInList = 0;
+      for(i=0;i<t->number_cmap_windows;i++)
+      {
+	if (t->cmap_windows[i] == win)
+	  bWinInList = 1;
+	if (t->cmap_windows[i] == t->w)
+	  bParentInList = 1;
+      }
+      if (bWinInList)
+      {
+	if (bParentInList)
+	{
+	  InstallWindowColormaps(t);
+        }
+	else
+	{
+	  InstallWindowColormaps(NULL);
+	}
+	return;
+      }
+    }
+  }
+  return;
+}
+/* END PATCH */
