@@ -83,6 +83,8 @@
 #include "gnome.h"
 #include "borders.h"
 #include "colormaps.h"
+#include "add_window.h"
+#include "icccm2.h"
 #ifdef HAVE_STROKE
 #include <errno.h>
 #include "stroke.h"
@@ -205,8 +207,6 @@ void DispatchEvent(Bool preserve_Tmp_win)
 
   if (EventHandlerJumpTable[Event.type])
   {
-    /* clear the rubber band outline, this is NOP if it doesn't exist */
-    MoveOutline(Scr.Root, 0, 0, 0, 0);
     (*EventHandlerJumpTable[Event.type])();
   }
 
@@ -437,19 +437,6 @@ void HandleKeyPress(void)
 
   DBUG("HandleKeyPress","Routine Entered");
 
-  if (Tmp_win && HAS_SLOPPY_FOCUS(Tmp_win))
-  {
-    /* A hack to make root key bindings work with SloppyFocus */
-    Window w;
-
-    XQueryPointer(dpy, Scr.Root, &JunkRoot, &w, &JunkX, &JunkY,
-		  &JunkX, &JunkY, &JunkMask);
-    if (w == None)
-    {
-      Tmp_win = NULL;
-      Event.xany.window = Scr.Root;
-    }
-  }
   Context = GetContext(Tmp_win,&Event, &PressedW);
   PressedW = None;
 
@@ -742,7 +729,7 @@ void HandlePropertyNotify(void)
 		  AutoPlaceIcon(Tmp_win);
 		  if(Tmp_win->Desk == Scr.CurrentDesk)
 		    {
-		       if(Tmp_win->icon_w)
+		      if(Tmp_win->icon_w)
 			 XMapWindow(dpy, Tmp_win->icon_w);
 		      if(Tmp_win->icon_pixmap_w != None)
 			XMapWindow(dpy, Tmp_win->icon_pixmap_w);
@@ -784,7 +771,7 @@ void HandlePropertyNotify(void)
 	int new_width, new_height;
 	new_width = Tmp_win->frame_g.width;
 	new_height = Tmp_win->frame_g.height;
-	ConstrainSize(Tmp_win, &new_width, &new_height, 0, 0);
+	ConstrainSize(Tmp_win, &new_width, &new_height, 0, 0, False);
 	if((new_width != Tmp_win->frame_g.width)||
 	   (new_height != Tmp_win->frame_g.height))
 	  SetupFrame(Tmp_win,Tmp_win->frame_g.x, Tmp_win->frame_g.y,
@@ -902,7 +889,7 @@ void HandleExpose(void)
       else
 	{
 	  RedrawBorder(Tmp_win,(Scr.Hilite == Tmp_win),True,True,
-		    Event.xany.window);
+		       Event.xany.window);
 	}
     }
   return;
@@ -949,7 +936,7 @@ void HandleMapRequest(void)
    }
   HandleMapRequestKeepRaised(None, NULL);
 }
-void HandleMapRequestKeepRaised(Window KeepRaised,  FvwmWindow  *ReuseWin)
+void HandleMapRequestKeepRaised(Window KeepRaised, FvwmWindow *ReuseWin)
 {
   extern long isIconicState;
   extern Boolean PPosOverride;
@@ -1106,6 +1093,12 @@ void HandleMapNotify(void)
   if(Event.xmap.event != Event.xmap.window)
     return;
 
+  /* don't map if the event was caused by a de-iconify */
+  if (IS_DEICONIFY_PENDING(Tmp_win))
+  {
+    return;
+  }
+
   /*
       Make sure at least part of window is on this page
       before giving it focus...
@@ -1126,9 +1119,9 @@ void HandleMapNotify(void)
   XMapSubwindows(dpy, Tmp_win->frame);
 
   if(Tmp_win->Desk == Scr.CurrentDesk)
-    {
-      XMapWindow(dpy, Tmp_win->frame);
-    }
+  {
+    XMapWindow(dpy, Tmp_win->frame);
+  }
 
   if(IS_ICONIFIED(Tmp_win))
     BroadcastPacket(M_DEICONIFY, 3,
@@ -1174,17 +1167,18 @@ void HandleUnmapNotify(void)
   extern FvwmWindow *colormap_win;
   int    weMustUnmap;
   int    focus_grabbed = 0;
+  Bool must_return = False;
 
   DBUG("HandleUnmapNotify","Routine Entered");
 
   /*
    * Don't ignore events as described below.
    */
-  if((Event.xunmap.event != Event.xunmap.window) &&
+  if(Event.xunmap.event != Event.xunmap.window &&
      (Event.xunmap.event != Scr.Root || !Event.xunmap.send_event))
-    {
-      return;
-    }
+  {
+    must_return = True;
+  }
 
   /*
    * The July 27, 1988 ICCCM spec states that a client wishing to switch
@@ -1207,6 +1201,14 @@ void HandleUnmapNotify(void)
   if(!Tmp_win)
     return;
 
+  if (Event.xunmap.window == Tmp_win->frame)
+  {
+    SET_DEICONIFY_PENDING(Tmp_win , 0);
+  }
+
+  if (must_return)
+    return;
+
   if(weMustUnmap)
     XUnmapWindow(dpy, Event.xunmap.window);
 
@@ -1528,8 +1530,13 @@ void HandleEnterNotify(void)
   }
 
   /* make sure its for one of our windows */
-  if (!Tmp_win)
+  if (!Tmp_win) {
+  /* SUBWINDOW COLORMAP PATCH BY RANDY FRANK, RSI INC., BOULDER, COLORADO, USA */
+/* handle a subwindow cmap */
+    EnterSubWindowColormap(Event.xany.window);
+  /* END PATCH */
     return;
+  }
 
   if(HAS_MOUSE_FOCUS(Tmp_win) || HAS_SLOPPY_FOCUS(Tmp_win))
   {
@@ -1590,7 +1597,12 @@ void HandleLeaveNotify(void)
 		SetBorder(Scr.Hilite,False,True,True,None);
 	    }
 	}
-    }
+  /* SUBWINDOW COLORMAP PATCH BY RANDY FRANK, RSI INC., BOULDER, COLORADO, USA */
+    } else {
+      /* handle a subwindow cmap */
+        LeaveSubWindowColormap(Event.xany.window);
+   }
+  /* END PATCH */
 }
 
 
@@ -1704,9 +1716,9 @@ void HandleConfigureRequest(void)
       height = Tmp_win->orig_g.height;
     }
     else
-      {
-	height = Tmp_win->frame_g.height;
-      }
+    {
+      height = Tmp_win->frame_g.height;
+    }
 
     /* for restoring */
     if (cre->value_mask & CWBorderWidth)
@@ -1721,7 +1733,10 @@ void HandleConfigureRequest(void)
       y = cre->y - Tmp_win->boundary_width - Tmp_win->title_g.height;
     if (cre->value_mask & CWWidth)
       width = cre->width + 2*Tmp_win->boundary_width;
-    if (cre->value_mask & CWHeight)
+    if (cre->value_mask & CWHeight &&
+	/* patch to ignore height changes to astronomically large windows
+	 * (needed for XEmacs 20.4) */
+	cre->height < WINDOW_FREAKED_OUT_HEIGHT)
       height = cre->height+Tmp_win->title_g.height+2*Tmp_win->boundary_width;
 
     /*
@@ -1731,7 +1746,7 @@ void HandleConfigureRequest(void)
      * requested client window width; the inner height is the same as the
      * requested client window height plus any title bar slop.
      */
-    ConstrainSize(Tmp_win, &width, &height, 0, 0);
+    ConstrainSize(Tmp_win, &width, &height, 0, 0, False);
     h = (IS_SHADED(Tmp_win)) ? Tmp_win->frame_g.height : height;
     /* dont allow clients to resize maximized windows */
     if (!IS_MAXIMIZED(Tmp_win) || (width == Tmp_win->frame_g.width &&
@@ -2011,7 +2026,7 @@ int My_XNextEvent(Display *dpy, XEvent *event)
       if ((readPipes[i] >= 0) && FD_ISSET(readPipes[i], &in_fdset)) {
         if (read(readPipes[i], &targetWindow, sizeof(Window)) > 0) {
           DBUG("My_XNextEvent","calling HandleModuleInput");
-          HandleModuleInput(targetWindow,i);
+          HandleModuleInput(targetWindow, i, NULL);
 	} else {
           DBUG("My_XNextEvent","calling KillModule");
           KillModule(i,10);
