@@ -138,6 +138,7 @@ enum
   F_MENUSTYLE,
   F_MODULE,
   F_MODULE_PATH,
+  F_MODULE_SYNC,
   F_MOUSE,
   F_MOVECURSOR,
   F_MOVE_TO_DESK,
@@ -198,6 +199,7 @@ enum
   F_LOWER,
   F_MAXIMIZE,
   F_MOVE,
+  F_MOVE_SMOOTHNESS,
   F_MOVE_THRESHOLD,
   F_MOVE_TO_PAGE,
   F_PLACEAGAIN,
