@@ -51,7 +51,10 @@
 #include "virtual.h"
 #include "stack.h"
 #include "gnome.h"
+#include "colors.h"
+#include "colormaps.h"
 #include "module_interface.h"
+#include "icccm2.h"
 #include "libs/Colorset.h"
 
 #include <X11/Xproto.h>
@@ -105,6 +108,8 @@ static int parseCommandArgs(
   const char *command, char **argv, int maxArgc, const char **errorMsg);
 static void InternUsefulAtoms(void);
 static void InitVariables(void);
+static void usage(void);
+static int MappedNotOverride(Window w);
 
 XContext FvwmContext;		/* context for fvwm windows */
 XContext MenuContext;		/* context for fvwm menus */
@@ -496,6 +501,9 @@ int main(int argc, char **argv)
     Pdefault = True;
   }
 
+  /* make a copy of the visual stuff so that XorPixmap can swap with root */
+  SaveFvwmVisual();
+
 #ifdef SHAPE
   ShapesSupported = XShapeQueryExtension(dpy, &ShapeEventBase, &ShapeErrorBase);
 #endif /* SHAPE */
@@ -939,7 +947,7 @@ void SetRCDefaults(void)
  *
  ***********************************************************************/
 
-int MappedNotOverride(Window w)
+static int MappedNotOverride(Window w)
 {
   XWindowAttributes wa;
   Atom atype;
@@ -1532,7 +1540,6 @@ static void InitVariables(void)
   Scr.StdReliefGC = 0;
   Scr.StdShadowGC = 0;
   Scr.DrawGC = 0;
-  Scr.DrawPicture = NULL;
 
   /* zero all flags */
   memset(&Scr.flags, 0, sizeof(Scr.flags));
@@ -1551,6 +1558,7 @@ static void InitVariables(void)
 
   XGetWindowAttributes(dpy,Scr.Root,&(Scr.FvwmRoot.attr));
   Scr.root_pushes = 0;
+  Scr.fvwm_pushes = 0;
   Scr.pushed_window = &Scr.FvwmRoot;
   Scr.FvwmRoot.number_cmap_windows = 0;
 
@@ -1589,6 +1597,7 @@ static void InitVariables(void)
   Scr.SnapGridX = DEFAULT_SNAP_GRID_X;
   Scr.SnapGridY = DEFAULT_SNAP_GRID_Y;
   Scr.OpaqueSize = DEFAULT_OPAQUE_MOVE_SIZE;
+  Scr.MoveSmoothness = DEFAULT_MOVE_SMOOTHNESS;
   Scr.MoveThreshold = DEFAULT_MOVE_THRESHOLD;
   /* ClickTime is set to the positive value upon entering the event loop. */
   Scr.ClickTime = -DEFAULT_CLICKTIME;
@@ -1658,7 +1667,8 @@ void Reborder(void)
     RBW - 05/15/1998
     Grab the last window and work backwards: preserve stacking order on restart.
 */
-  for (tmp = Scr.FvwmRoot.stack_prev; tmp != &Scr.FvwmRoot; tmp = tmp->stack_prev)
+  for (tmp = Scr.FvwmRoot.stack_prev; tmp != &Scr.FvwmRoot;
+       tmp = tmp->stack_prev)
   {
     RestoreWithdrawnLocation (tmp,True);
     XUnmapWindow(dpy,tmp->frame);
@@ -1696,13 +1706,14 @@ void Done(int restart, char *command)
   const char *exitFuncName;
 
   if (!restart)
-    {
-      MoveViewport(0,0,False);
-    }
+  {
+    MoveViewport(0,0,False);
+  }
 
   /* migo (03/Jul/1999): execute [Session]ExitFunction */
   exitFuncName = getInitFunctionName(2);
-  if (FindFunction(exitFuncName)) {
+  if (FindFunction(exitFuncName))
+  {
     char *action = strdup(CatString2("Function ", exitFuncName));
     ExecuteFunction(action, NULL, &Event, C_ROOT, -1, EXPAND_COMMAND);
     free(action);
@@ -1723,9 +1734,11 @@ void Done(int restart, char *command)
     Bool doPreserveState = True;
     SaveDesktopState();
 
-    if (command) {
+    if (command)
+    {
       while (isspace(command[0])) command++;
-      if (strncmp(command, "--dont-preserve-state", 21) == 0) {
+      if (strncmp(command, "--dont-preserve-state", 21) == 0)
+      {
         doPreserveState = False;
         command += 21;
         while (isspace(command[0])) command++;
@@ -1756,7 +1769,8 @@ void Done(int restart, char *command)
     sleep(1);
     ReapChildren();
 
-    if (command) {
+    if (command)
+    {
 #define MAX_ARG_SIZE 25
 #if 0
       /* This is not allowed by ANSI C! Must use a macro. */
@@ -1766,16 +1780,23 @@ void Done(int restart, char *command)
       const char *errorMsg;
       int n = parseCommandArgs(command, my_argv, MAX_ARG_SIZE, &errorMsg);
 
-      if (n <= 0) {
+      if (n <= 0)
+      {
         fvwm_msg(ERR, "Done", "Restart command parsing error in (%s): [%s]",
           command, errorMsg);
-
-      } else if (StrEquals(my_argv[0], "--pass-args")) {
-        if (n != 2) {
-          fvwm_msg(ERR, "Done", "Restart --pass-args: single name expected. (restarting '%s' instead)",
+      }
+      else if (StrEquals(my_argv[0], "--pass-args"))
+      {
+        if (n != 2)
+	{
+          fvwm_msg(ERR, "Done",
+		   "Restart --pass-args: single name expected. "
+		   "(restarting '%s' instead)",
             g_argv[0]);
 
-        } else {
+        }
+	else
+	{
           int i;
           my_argv[0] = my_argv[1];
           for (i = 1; i < g_argc && i < MAX_ARG_SIZE - 1; i++)
@@ -1789,7 +1810,9 @@ void Done(int restart, char *command)
           perror("  system error description");
         }
 
-      } else {
+      }
+      else
+      {
         execvp(my_argv[0], my_argv);
         fvwm_msg(ERR, "Done", "Call of '%s' failed! (restarting '%s' instead)",
           my_argv[0], g_argv[0]);
@@ -1858,7 +1881,7 @@ int FvwmErrorHandler(Display *dpy, XErrorEvent *event)
   return 0;
 }
 
-void usage(void)
+static void usage(void)
 {
 #if 0
   fvwm_msg(INFO,"usage","\nFvwm Version %s Usage:\n\n",VERSION);
@@ -1947,14 +1970,14 @@ static int parseCommandArgs(
   int argc;
   char *aptr = argString;
   const char *cptr = command;
-  #define theChar (*cptr)
-  #define advChar (cptr++)
-  #define topChar (*cptr     == '\\'? *(cptr+1): *cptr)
-  #define popChar (*(cptr++) == '\\'? *(cptr++): *(cptr-1))
-  #define canAddArgChar (totalArgLen < MAX_TOTAL_ARG_LEN-1)
-  #define addArgChar(ch) (++totalArgLen, *(aptr++) = ch)
-  #define canAddArgStr(str) (totalArgLen < MAX_TOTAL_ARG_LEN-strlen(str))
-  #define addArgStr(str) {const char *tmp = str; while (*tmp) { addArgChar(*(tmp++)); }}
+#define theChar (*cptr)
+#define advChar (cptr++)
+#define topChar (*cptr     == '\\'? *(cptr+1): *cptr)
+#define popChar (*(cptr++) == '\\'? *(cptr++): *(cptr-1))
+#define canAddArgChar (totalArgLen < MAX_TOTAL_ARG_LEN-1)
+#define addArgChar(ch) (++totalArgLen, *(aptr++) = ch)
+#define canAddArgStr(str) (totalArgLen < MAX_TOTAL_ARG_LEN-strlen(str))
+#define addArgStr(str) {const char *tmp = str; while (*tmp) { addArgChar(*(tmp++)); }}
 
   *errorMsg = "";
   if (!command) { *errorMsg = "No command"; return -1; }
