@@ -2,8 +2,8 @@
 /* GNOME WM Compliance adapted for FVWM                  */
 /* Properties set on the root window (or desktop window) */
 /*                                                       */
-/* Even though the rest of E is GPL consider this file   */
-/* Public Domain - use it howvere you see fit to make    */
+/* Even though the rest of fvwm is GPL consider this file*/
+/* Public Domain - use it however you see fit to make    */
 /* your WM GNOME compiant                                */
 /*                                                       */
 /* written by Raster                                     */
@@ -29,6 +29,7 @@
 #include "screen.h"
 #include "misc.h"
 #include "stack.h"
+#include "virtual.h"
 
 
 
@@ -99,7 +100,7 @@
 /*      6 = Dock (always on top - for panel) */
 /* The app sets this alone, not the WM. If this property changes the WM */
 /* should comply and change the appearance/behavior of the Client window */
-/* if this hint does nto exist the WM Will create it ont he Client window */
+/* if this hint does not exist the WM Will create it on the Client window */
 #define WIN_LAYER_DESKTOP                0
 #define WIN_LAYER_BELOW                  2
 #define WIN_LAYER_NORMAL                 4
@@ -245,7 +246,7 @@
 static Window __button_proxy = 0;
 
 
-void *
+static void *
 AtomGet(Window win, Atom to_get, Atom type, int *size)
 {
   unsigned char      *retval;
@@ -316,7 +317,7 @@ GNOME_GetHintLayer(FvwmWindow *fwin)
    retval = AtomGet(fwin->w, atom_get, XA_CARDINAL, &size);
    if (retval)
      {
-	fwin->layer = *retval;
+	set_layer(fwin, *retval);
 	free(retval);
      }
 }
@@ -470,7 +471,7 @@ GNOME_GetHints(FvwmWindow *fwin)
 /* this duplicates most of the above... and it assumes
    that style is inizialized to zero.
  */
-void 
+void
 GNOME_GetStyle (FvwmWindow *fwin, window_style *style)
 {
   Atom atom_get;
@@ -483,13 +484,16 @@ GNOME_GetStyle (FvwmWindow *fwin, window_style *style)
   if (retval)
     {
       style->start_desk = *(int*)retval;
+      /* Allow special case of -1 to work. */
+      if (style->start_desk > -1)
+	style->start_desk++;
       style->flags.use_start_on_desk = 1;
       style->flag_mask.use_start_on_desk = 1;
       free(retval);
     }
 
   /* Icons - not implemented */
-  
+
   /* Layer */
   atom_get = XInternAtom(dpy, XA_WIN_LAYER, False);
   retval = AtomGet(fwin->w, atom_get, XA_CARDINAL, &size);
@@ -504,12 +508,12 @@ GNOME_GetStyle (FvwmWindow *fwin, window_style *style)
   retval = AtomGet(fwin->w, atom_get, XA_CARDINAL, &size);
   if (retval)
     {
-      if (*(int*)retval & WIN_STATE_STICKY) 
+      if (*(int*)retval & WIN_STATE_STICKY)
 	{
           style->flags.common.is_sticky = 1;
           style->flag_mask.common.is_sticky = 1;
 	}
-      
+
       if (*(int*)retval & WIN_STATE_SHADED)
 	{
 	  /* unimplemented, since we don't have a
@@ -521,7 +525,7 @@ GNOME_GetStyle (FvwmWindow *fwin, window_style *style)
       if (*(int*)retval & WIN_STATE_FIXED_POSITION)
 	{
           style->flags.common.is_fixed = 1;
-          style->flag_mask.common.is_fixed = 1;	  
+          style->flag_mask.common.is_fixed = 1;
 	}
 
       free(retval);
@@ -568,7 +572,7 @@ GNOME_SetLayer(FvwmWindow *fwin)
   int val;
 
   atom_set = XInternAtom(dpy, XA_WIN_LAYER, False);
-  val = fwin->layer;
+  val = get_layer(fwin);
   XChangeProperty(dpy, fwin->w, atom_set, XA_CARDINAL, 32,
 		  PropModeReplace, (unsigned char *)&val, 1);
 }
@@ -622,7 +626,9 @@ GNOME_SetDeskCount(void)
 
   atom_set = XInternAtom(dpy, XA_WIN_WORKSPACE_COUNT, False);
   val = Scr.CurrentDesk;
-  for (t = Scr.FvwmRoot.stack_next; t != &Scr.FvwmRoot; t = t->stack_next)
+  for (t = get_next_window_in_stack_ring(&Scr.FvwmRoot);
+       t != &Scr.FvwmRoot;
+       t = get_next_window_in_stack_ring(t))
     {
       if (t->Desk > val)
 	{
