@@ -60,8 +60,8 @@ struct queue_buff_struct **pipeQueue;
 
 extern fd_set init_fdset;
 
-void DeleteQueueBuff(int module);
-void AddToQueue(int module, unsigned long *ptr, int size, int done);
+static void DeleteQueueBuff(int module);
+static void AddToQueue(int module, unsigned long *ptr, int size, int done);
 
 void initModules(void)
 {
@@ -112,12 +112,11 @@ void ClosePipes(void)
     }
 }
 
-
-void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
-		     unsigned long context, char *action,int* Module)
+static int do_execute_module(F_CMD_ARGS)
 {
   int fvwm_to_app[2],app_to_fvwm[2];
   int i,val,nargs = 0;
+  int ret_pipe;
   char *cptr;
   char *args[20];
   char *arg1 = NULL;
@@ -133,7 +132,7 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
     UngrabEm();
 
   if(action == NULL)
-    return;
+    return -1;
 
   if(tmp_win)
     win = tmp_win->w;
@@ -146,7 +145,7 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 
   action = GetNextToken(action, &cptr);
   if (!cptr)
-    return;
+    return -1;
 
   arg1 = searchPath( ModulePath, cptr, EXECUTABLE_EXTENSION, X_OK );
 
@@ -155,7 +154,7 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
       fvwm_msg(ERR,"executeModule",
 	       "No such module '%s' in ModulePath '%s'",cptr,ModulePath);
       free(cptr);
-      return;
+      return -1;
     }
 
 #ifdef REMOVE_EXECUTABLE_EXTENSION
@@ -175,8 +174,9 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
       fvwm_msg(ERR,"executeModule","Too many Accessories!");
       free(arg1);
       free(cptr);
-      return;
+      return -1;
     }
+  ret_pipe = i;
 
   /* I want one-ended pipes, so I open two two-ended pipes,
    * and close one end of each. I need one ended pipes so that
@@ -186,7 +186,7 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
       fvwm_msg(ERR,"executeModule","Failed to open pipe");
       free(arg1);
       free(cptr);
-      return;
+      return -1;
     }
   if(pipe(app_to_fvwm)!=0)
     {
@@ -195,7 +195,7 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
       free(cptr);
       close(fvwm_to_app[0]);
       close(fvwm_to_app[1]);
-      return;
+      return -1;
     }
 
   pipeName[i] = stripcpy(cptr);
@@ -308,14 +308,135 @@ void executeModule(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 	  if(args[i] != 0)
 	    free(args[i]);
 	}
+      return -1;
     }
+
+  return ret_pipe;
+}
+
+void executeModule(F_CMD_ARGS)
+{
+  do_execute_module(eventp, w, tmp_win, context, action, Module);
   return;
 }
 
-/* Changed message from module from 255 to 1000. dje */
-int HandleModuleInput(Window w, int channel)
+void executeModuleSync(F_CMD_ARGS)
 {
-  char text[1000];
+  int sec = 0;
+  char *next;
+  char *token;
+  char *expect = NULL;
+  struct timeval timeout = {42, 0};
+  struct timeval *timeoutP = &timeout;
+  int pipe_slot;
+  fd_set in_fdset;
+  fd_set out_fdset;
+  Window targetWindow;
+  extern fd_set_size_t fd_width;
+
+  if (!action)
+    return;
+
+  token = PeekToken(action, &next);
+  if (StrEquals(token, "expect"))
+  {
+    token = PeekToken(next, &next);
+    if (token)
+    {
+      expect = alloca(strlen(token) + 1);
+      strcpy(expect, token);
+    }
+    action = next;
+    token = PeekToken(action, &next);
+  }
+  if (token && StrEquals(token, "timeout"))
+  {
+    if (GetIntegerArguments(next, &next, &sec, 1) > 0 && sec > 0)
+    {
+      /* we have a delay, skip the number */
+      action = next;
+    }
+    else
+    {
+      fvwm_msg(ERR, "executeModuleSync", "illegal timeout");
+      return;
+    }
+  }
+
+  if (!action)
+  {
+    /* no module name */
+    return;
+  }
+
+  pipe_slot = do_execute_module(eventp, w, tmp_win, context, action, Module);
+  if (pipe_slot == -1)
+  {
+    /* executing the module failed, just return */
+    return;
+  }
+
+  /* wait for the message from the module */
+
+  /* wait for module input */
+  while (1)
+  {
+    if (sec > 0)
+    {
+      timeout.tv_sec = sec;
+      timeout.tv_usec = 0;
+      timeoutP = &timeout;
+    }
+    else
+    {
+      timeoutP = NULL;
+    }
+
+    FD_ZERO(&in_fdset);
+    FD_ZERO(&out_fdset);
+    if(readPipes[pipe_slot] >= 0)
+      FD_SET(readPipes[pipe_slot], &in_fdset);
+    if(pipeQueue[pipe_slot]!= NULL)
+      FD_SET(writePipes[pipe_slot], &out_fdset);
+
+    if (fvwmSelect(fd_width, &in_fdset, &out_fdset, 0, timeoutP) > 0)
+    {
+      if ((readPipes[pipe_slot] >= 0) &&
+	  FD_ISSET(readPipes[pipe_slot], &in_fdset))
+      {
+	/* Check for module input. */
+	if (read(readPipes[pipe_slot], &targetWindow, sizeof(Window)) > 0)
+	{
+	  if (HandleModuleInput(targetWindow, pipe_slot, expect) == 77)
+	  {
+	    /* we got the message we were waiting for */
+	    return;
+	  }
+	}
+	else
+	{
+	  KillModule(pipe_slot, 10);
+	}
+      }
+      if ((writePipes[pipe_slot] >= 0) &&
+	  FD_ISSET(writePipes[pipe_slot], &out_fdset))
+      {
+        FlushQueue(pipe_slot);
+      }
+    }
+    else
+    {
+      /* timeout */
+      return;
+    }
+  }
+}
+
+
+/* Changed message from module from 255 to 1000. dje */
+int HandleModuleInput(Window w, int channel, char *expect)
+{
+  char text[MAX_MODULE_INPUT_TEXT_LEN];
   int size;
   int cont,n;
   extern FvwmWindow *ButtonWindow;
@@ -368,6 +489,17 @@ int HandleModuleInput(Window w, int channel)
         return 66;
       }
 
+      if (expect && strncasecmp(text, expect, strlen(expect)) == 0)
+      {
+	/* the module sent the expected string */
+	return 77;
+      }
+      else if (!expect && strncasecmp(text, "FINISHED_STARTUP", 16) == 0)
+      {
+	/* module has finished startup */
+	return 77;
+      }
+
       /* perhaps the module would like us to kill it? */
       if(strncasecmp(text,"KillMe",6)==0)
       {
@@ -609,7 +741,7 @@ static void BroadcastNewPacket(unsigned long event_type,
 
   for (i=0; i<npipes; i++)  {
     PositiveWrite(i, (void *) &body, plen);
-    }
+  }
 }
 
 
@@ -922,12 +1054,18 @@ BroadcastMiniIcon(unsigned long event_type,
 void BroadcastColorset(int n)
 {
   int i;
+  char *buf;
 
   if (-1 == n)
     return;
 
+  buf = DumpColorset(n);
   for (i=0; i < npipes; i++)
-    SendName(i, M_CONFIG_INFO, 0, 0, 0, DumpColorset(n));
+  {
+    /* just a quick check to save us lots of overhead */
+    if (pipeOn[i] >= 0)
+      SendName(i, M_CONFIG_INFO, 0, 0, 0, buf);
+  }
 }
 
 
@@ -985,7 +1123,7 @@ int PositiveWrite(int module, unsigned long *ptr, int size)
     return -1;
 
   /*
-   * fvwm2  recapture has the x  server grabbed while  iconify events are
+   * fvwm   recapture has the x  server grabbed while  iconify events are
    * simulated.  Right now (01/24/99), the only module using lock on send
    * is FvwmAnimate which always  does  a grab of  its  own.  To avoid  a
    * deadlock, iconify events are not sent to a lock on send module while
@@ -1009,7 +1147,7 @@ int PositiveWrite(int module, unsigned long *ptr, int size)
     FlushQueue(module);
     fcntl(readPipes[module],F_SETFL,0);
     while ((e = read(readPipes[module],&targetWindow, sizeof(Window))) > 0) {
-      if (HandleModuleInput(targetWindow,module) == 66) {
+      if (HandleModuleInput(targetWindow, module, NULL) == 66) {
         break;
       }
     }
@@ -1022,7 +1160,7 @@ int PositiveWrite(int module, unsigned long *ptr, int size)
 }
 
 
-void AddToQueue(int module, unsigned long *ptr, int size, int done)
+static void AddToQueue(int module, unsigned long *ptr, int size, int done)
 {
   struct queue_buff_struct *c,*e;
   unsigned long *d;
@@ -1046,7 +1184,7 @@ void AddToQueue(int module, unsigned long *ptr, int size, int done)
   e->next = c;
 }
 
-void DeleteQueueBuff(int module)
+static void DeleteQueueBuff(int module)
 {
   struct queue_buff_struct *a;
 
