@@ -1,4 +1,4 @@
-/* This program is free software; you can redistribute it and/or modify
+#/* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -16,7 +16,7 @@
 #ifndef _MOVE_RESIZE_
 #define _MOVE_RESIZE_
 
-void MoveOutline(Window root, int x, int  y, int  width, int height);
+void MoveOutline(int x, int  y, int  width, int height);
 void AnimatedMoveOfWindow(Window w,int startX,int startY,int endX,
 			  int endY,Bool fWarpPointerToo,
 			  int cusDelay, float *ppctMovement);
@@ -31,9 +31,16 @@ void move_window_doit(XEvent *eventp,Window w,FvwmWindow *tmp_win,
 		      Bool fAnimated, Bool fMoveToPage);
 void animated_move_window(F_CMD_ARGS);
 void move_window_to_page(F_CMD_ARGS);
+void SetMoveSmoothness(F_CMD_ARGS);
+void SetMoveThreshold(F_CMD_ARGS);
+void SetOpaque(F_CMD_ARGS);
+void SetSnapAttraction(F_CMD_ARGS);
+void SetSnapGrid(F_CMD_ARGS);
+void SetXOR(F_CMD_ARGS);
+void SetXORPixmap(F_CMD_ARGS);
 void resize_window(F_CMD_ARGS);
 void ConstrainSize(FvwmWindow *, unsigned int *width, unsigned int *height,
-		   int xmotion, int ymotion);
+		   int xmotion, int ymotion, Bool roundUp);
 void Maximize(F_CMD_ARGS);
 
 #endif /* _MOVE_RESIZE_ */
