@@ -76,8 +76,7 @@ typedef enum {
 #endif
     SimpleButton                ,
 #ifdef GRADIENT_BUTTONS
-    HGradButton                 ,
-    VGradButton                 ,
+    GradientButton              ,
 #endif
 #ifdef PIXMAP_BUTTONS
     PixmapButton                ,
@@ -97,7 +96,7 @@ enum {
 
     /* specific style flags */
     /* justification bits (3.17 -> 4 bits) */
-    HOffCenter                  = (1<<4),
+    HOffCenter                  = (1<<12),
     HRight                      = (1<<5),
     VOffCenter                  = (1<<6),
     VBottom                     = (1<<7),
@@ -111,6 +110,7 @@ enum {
 #endif
     FlatButton                  = (1<<10),
     SunkButton                  = (1<<11)
+    /* 12 use above! */
 };
 
 #ifdef BORDERSTYLE
@@ -132,6 +132,7 @@ typedef struct ButtonFace {
 	struct {
 	    int npixels;
 	    Pixel *pixels;
+	    char gradient_type;
 	} grad;
 #endif
 #ifdef VECTOR_BUTTONS
@@ -237,6 +238,8 @@ typedef struct ScreenInfo
 
   int root_pushes;		/* current push level to install root
 				   colormap windows */
+  int fvwm_pushes;		/* current push level to install fvwm
+				   colormap windows */
   FvwmWindow *pushed_window;	/* saved window to install when pushes drops
 				   to zero */
   Cursor *FvwmCursors;
@@ -260,7 +263,6 @@ typedef struct ScreenInfo
   GC StdShadowGC;
 
   GC DrawGC;			/* GC to draw lines for move and resize */
-  Picture *DrawPicture;
   GC ScratchGC1;
   GC ScratchGC2;
   GC ScratchGC3;
@@ -299,6 +301,7 @@ typedef struct ScreenInfo
   int ClickTime;               /*Max button-click delay for Function built-in*/
   int ScrollResistance;        /* resistance to scrolling in desktop */
   int MoveResistance;          /* res to moving windows over viewport edge */
+  int MoveSmoothness;
   int MoveThreshold;           /* number of pixels of mouse motion to decide
 				* it's a move operation */
   int SnapAttraction;          /* attractiveness of window edges */
