@@ -72,8 +72,11 @@ static double c400_distance(XColor *, XColor *);
 static Picture *PictureList=NULL;
 Bool Pdefault;
 Visual *Pvisual;
+static Visual *FvwmVisual;
 Colormap Pcmap;
+static Colormap FvwmCmap;
 unsigned int Pdepth;
+static unsigned int FvwmDepth;
 Display *Pdpy;            /* Save area for display pointer */
 
 void InitPictureCMap(Display *dpy) {
@@ -81,7 +84,8 @@ void InitPictureCMap(Display *dpy) {
 
   Pdpy = dpy;
   /* if fvwm has not set this env-var it is using the default visual */
-  if ((envp = getenv("FVWM_VISUALID")) != NULL) {
+  envp = getenv("FVWM_VISUALID");
+  if ((envp != NULL) && (strlen(envp) > 0)) {
     /* convert the env-vars to a visual and colormap */
     int viscount;
     XVisualInfo vizinfo, *xvi;
@@ -94,13 +98,39 @@ void InitPictureCMap(Display *dpy) {
     Pdefault = False;
   } else {
     int screen = DefaultScreen(dpy);
+
     Pvisual = DefaultVisual(dpy, screen);
     Pdepth = DefaultDepth(dpy, screen);
     Pcmap = DefaultColormap(dpy, screen);
     Pdefault = True;
   }
+  FvwmVisual = Pvisual;
+  FvwmDepth = Pdepth;
+  FvwmCmap = Pcmap;
 }
 
+void UseDefaultVisual(void)
+{
+  int screen = DefaultScreen(Pdpy);
+
+  Pvisual = DefaultVisual(Pdpy, screen);
+  Pdepth = DefaultDepth(Pdpy, screen);
+  Pcmap = DefaultColormap(Pdpy, screen);  
+}
+
+void UseFvwmVisual(void)
+{
+  Pvisual = FvwmVisual;
+  Pdepth = FvwmDepth;
+  Pcmap = FvwmCmap;
+}
+
+void SaveFvwmVisual(void)
+{
+  FvwmVisual = Pvisual;
+  FvwmDepth = Pdepth;
+  FvwmCmap = Pcmap;
+}
 
 static char* imagePath = FVWM_IMAGEPATH;
 
@@ -134,7 +164,7 @@ char* findImageFile( const char* icon, const char* pathlist, int type )
 }
 
 
-Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
+Picture *LoadPicture(Display *dpy, Window Root, char *path, int color_limit)
 {
   int l;
   Picture *p;
@@ -155,7 +185,7 @@ Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
   xpm_attributes.colormap = Pcmap;
   xpm_attributes.depth = Pdepth;
   xpm_attributes.closeness=40000; /* Allow for "similar" colors */
-  xpm_attributes.valuemask = XpmSize | XpmReturnPixels | XpmCloseness
+  xpm_attributes.valuemask = XpmSize | XpmReturnAllocPixels | XpmCloseness
 			     | XpmVisual | XpmColormap | XpmDepth;
 
   rc = XpmReadFileToXpmImage(path, &my_image, NULL);
@@ -168,6 +198,8 @@ Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
       p->height = my_image.height;
       p->depth = Pdepth;
       XpmFreeXpmImage(&my_image);
+      p->alloc_pixels = xpm_attributes.alloc_pixels;
+      p->nalloc_pixels = xpm_attributes.nalloc_pixels;
       return p;
     }
     XpmFreeXpmImage(&my_image);
@@ -180,6 +212,7 @@ Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
     {
       p->depth = 0;
       p->mask = None;
+      p->nalloc_pixels = 0;
       return p;
     }
 
@@ -188,8 +221,8 @@ Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
 }
 
 
-Picture *GetPicture(Display *dpy, Window Root,
-		    char *ImagePath, char *name, int color_limit)
+Picture *GetPicture(Display *dpy, Window Root, char *ImagePath, char *name,
+		    int color_limit)
 {
     char *path = findImageFile( name, ImagePath, R_OK );
     Picture *p;
@@ -197,14 +230,13 @@ Picture *GetPicture(Display *dpy, Window Root,
     if ( path == NULL )
 	return NULL;
 
-    p = LoadPicture( dpy, Root, path, color_limit );
+    p = LoadPicture(dpy, Root, path, color_limit);
     if ( p == NULL )
 	free(path);
 
     return p;
 }
 
-
 Picture *CachePicture(Display *dpy, Window Root,
 		      char *ImagePath, char *name, int color_limit)
 {
@@ -256,6 +288,10 @@ void DestroyPicture(Display *dpy, Picture *p)
     return;
 
   /* Let it fly */
+  if (p->nalloc_pixels != 0) {
+    XFreeColors(dpy, Pcmap, p->alloc_pixels, p->nalloc_pixels, 0);
+    free(p->alloc_pixels);
+  }
   if(p->name!=NULL)
     free(p->name);
   if(p->picture!=None)
