@@ -1,7 +1,4 @@
-/* Rewrite of this file by Dominik Vogt on Nov-1-1998 to remove the
- * Xconsortium copyright.
- *
- * This program is free software; you can redistribute it and/or modify
+/* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
@@ -28,30 +25,17 @@ unsigned long GetColor(char *name)
   XColor color;
 
   color.pixel = 0;
-  if (!XParseColor (dpy, DefaultColormap(dpy,screen), name, &color)) 
+  if (!XParseColor (dpy, DefaultColormap(dpy,screen), name, &color))
     {
       fprintf(stderr,"%s:  unknown color \"%s\"\n",Module,name);
       exit(1);
     }
-  else if(!XAllocColor (dpy, DefaultColormap(dpy,screen), &color)) 
+  else if(!XAllocColor (dpy, DefaultColormap(dpy,screen), &color))
     {
       fprintf(stderr, "%s:  unable to allocate color for \"%s\"\n",
 	      Module, name);
       exit(1);
     }
 
-  /* Dominik Vogt: in the original code there was this:
-   *
-   * #define Dynamic 1
-   *
-   * if ((ecolor.pixel != BlackPixel(dpy, screen)) &&
-   *	(ecolor.pixel != WhitePixel(dpy, screen)) &&
-   *	(DefaultVisual(dpy, screen)->class & Dynamic))
-   * return(ecolor.pixel);
-   *
-   * If the condition is true, the value is returned, if not, some random
-   * value from the stack was used instead. If anybody knows what this is
-   * good for feel free to change this. */
-
   return color.pixel;
 }
