@@ -1,6 +1,6 @@
 /*
-   FvwmButtons, copyright 1996, Jarl Totland
-
+ * FvwmButtons, copyright 1996, Jarl Totland
+ *
  * This module, and the entire GoodStuff program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
@@ -9,8 +9,8 @@
  * are provided or implied in any way whatsoever. Use this program at your
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact.
-
-*/
+ *
+ */
 
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -79,6 +79,9 @@
 				 * altered */
 #define b_PosFixed   0x00080000 /* User provided button position */
 #define b_SizeSmart  0x00100000 /* Improved button box sizing */
+#define b_Colorset   0x00200000 /* use colorset instead of fore/back colours */
+#define b_ColorsetParent 0x00400000 /* Parent has a colorset background */
+#define b_Panel      0x00800000 /* similar to swallow, but drawn differently */
 
 /* Flags for b->swallow */
 #define b_Count       0x03 /* Init counter for swallowing */
@@ -107,9 +110,10 @@ struct container_info_struct
   int num_buttons;
   int num_columns;
   int num_rows;
-  int ButtonWidth;
-  int ButtonHeight;
-  int xpos,ypos;
+  int xpos;
+  int ypos;
+  int width;
+  int height;
 
   unsigned long flags;     /* Which data are set in this container? */
   byte justify;            /* b_Justify */
@@ -126,6 +130,7 @@ struct container_info_struct
   char *back;              /* b_Back && !b_IconBack */
   char *back_file;         /* b_Back && b_IconBack */
   char *fore;              /* b_Fore */
+  int colorset;            /* b_Colorset */
   Pixel fc;                /* b_Fore */
   Pixel bc,hc,sc;          /* b_Back && !b_IconBack */
   Picture *backicon;       /* b_Back && b_IconBack */
@@ -149,8 +154,9 @@ struct button_info_struct
   char *font_string;       /* b_Font */
   char *back;              /* b_Back */
   char *fore;              /* b_Fore */
+  int colorset;            /* b_Colorset */
   byte xpad,ypad;          /* b_Padding */
-  signed char framew;             /* b_Frame */
+  signed char framew;      /* b_Frame */
   byte justify;            /* b_Justify */
   byte justify_mask;       /* b_Justify */
   container_info *c;       /* b_Container */
@@ -158,12 +164,13 @@ struct button_info_struct
   char **action;           /* b_Action */
   char *icon_file;         /* b_Icon */
   char *hangon;            /* b_Hangon || b_Swallow */
-  Window IconWin;          /* b_Icon || b_Swallow */
   Pixel fc;                /* b_Fore */
   Pixel bc,hc,sc;          /* b_Back && !b_IconBack */
-  Picture *backicon;       /* b_Back && b_IconBack */
   ushort minx,miny;        /* b_Size */
   Picture *icon;           /* b_Icon */
+  Picture *backicon;       /* b_Back && b_IconBack */
+  Window IconWin;          /* b_Icon || b_Swallow */
+  Window BackIconWin;      /* b_Back && b_IconBack */
 
   byte swallow;            /* b_Swallow */
   byte swallow_mask;       /* b_Swallow */
@@ -173,6 +180,21 @@ struct button_info_struct
   char *spawn;             /* b_Swallow */
   int x,y;                 /* b_Swallow */
   ushort w,h,bw;           /* b_Swallow */
+
+  struct
+  {
+    unsigned is_panel : 1;     /* b_Panel */
+    unsigned panel_mapped : 1; /* b_Panel */
+    unsigned panel_iconified : 1; /* b_Panel */
+    unsigned panel_shaded : 1; /* b_Panel */
+  } newflags;
+#define SLIDE_UP 0
+#define SLIDE_DOWN 1
+#define SLIDE_LEFT 2
+#define SLIDE_RIGHT 3
+  char slide_direction;        /* b_Panel */
+  int slide_steps;             /* b_Panel */
+  int slide_delay_ms;          /* b_Panel */
 };
 
 struct panel_info_struct
