@@ -1,6 +1,6 @@
 /*
-   FvwmButtons, copyright 1996, Jarl Totland
-
+ * FvwmButtons, copyright 1996, Jarl Totland
+ *
  * This module, and the entire GoodStuff program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
@@ -9,8 +9,8 @@
  * are provided or implied in any way whatsoever. Use this program at your
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact.
-
-*/
+ *
+ */
 
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,9 +35,51 @@
 #include <stdio.h>
 #include <X11/Intrinsic.h>
 #include "FvwmButtons.h"
+#include "button.h"
 
 extern char *MyName;
 
+
+int buttonXPos(button_info *b, int i)
+{
+  int column = i % b->parent->c->num_columns;
+
+  return b->parent->c->xpos +
+    (b->parent->c->width * column / b->parent->c->num_columns);
+}
+
+int buttonYPos(button_info *b, int i)
+{
+  int row = i / b->parent->c->num_columns;
+
+  return b->parent->c->ypos +
+    (b->parent->c->height * row / b->parent->c->num_rows);
+}
+
+int buttonWidth(button_info *b)
+{
+  int column = b->n % b->parent->c->num_columns;
+  int column2 = column + b->BWidth;
+
+  return (b->parent->c->width * column2 / b->parent->c->num_columns) -
+    (b->parent->c->width * column / b->parent->c->num_columns);
+}
+
+int buttonHeight(button_info *b)
+{
+  int row = b->n / b->parent->c->num_columns;
+  int row2 = row + b->BHeight;
+
+  return (b->parent->c->height * row2 / b->parent->c->num_rows) -
+    (b->parent->c->height * row / b->parent->c->num_rows);
+}
+
+int buttonSwallowCount(button_info *b)
+{
+  return (b->flags & (b_Swallow | b_Panel)) ? (b->swallow & b_Count) : 0;
+}
+
+
 /**
 *** buttonInfo()
 *** Give lots of info for this button: XPos, YPos, XPad, YPad, Frame(signed)
@@ -53,30 +95,30 @@ void buttonInfo(button_info *b,int *x,int *y,int *px,int *py,int *f)
   w&=~(b->flags&(b_Frame|b_Padding));
 
   if(b->flags&b_Container && w&b_Frame)
-    {
-      *f=0;
-      w&=~b_Frame;
-    }
+  {
+    *f=0;
+    w&=~b_Frame;
+  }
   if((b->flags&b_Container || b->flags&b_Swallow) && w&b_Padding)
-    {
-      *px=*py=0;
-      w&=~b_Padding;
-    }
+  {
+    *px=*py=0;
+    w&=~b_Padding;
+  }
 
   while(w && (b=b->parent))
+  {
+    if(w&b_Frame && b->c->flags&b_Frame)
     {
-      if(w&b_Frame && b->c->flags&b_Frame)
-	{
-	  *f=b->c->framew;
-	  w&=~b_Frame;
-	}
-      if(w&b_Padding && b->c->flags&b_Padding)
-	{
-	  *px=b->c->xpad;
-	  *py=b->c->ypad;
-	  w&=~b_Padding;
-	}
+      *f=b->c->framew;
+      w&=~b_Frame;
     }
+    if(w&b_Padding && b->c->flags&b_Padding)
+    {
+      *px=b->c->xpad;
+      *py=b->c->ypad;
+      w&=~b_Padding;
+    }
+  }
 }
 
 /**
@@ -200,9 +242,11 @@ Pixel buttonFore(button_info *b)
 {
   if(b->flags&b_Fore)
     return b->fc;
-  while((b=b->parent))
+  while ((b=b->parent))
+  {
     if(b->c->flags&b_Fore)
       return b->c->fc;
+  }
 #ifdef DEBUG
   fprintf(stderr,"%s: BUG: No foreground definition?\n",MyName);
 #endif
@@ -218,8 +262,10 @@ Pixel buttonBack(button_info *b)
   if(b->flags&b_Back)
     return b->bc;
   while((b=b->parent))
+  {
     if(b->c->flags&b_Back)
       return b->c->bc;
+  }
 #ifdef DEBUG
   fprintf(stderr,"%s: BUG: No background definition?\n",MyName);
 #endif
@@ -235,8 +281,10 @@ Pixel buttonHilite(button_info *b)
   if(b->flags&b_Back)
     return b->hc;
   while((b=b->parent))
+  {
     if(b->c->flags&b_Back)
       return b->c->hc;
+  }
 #ifdef DEBUG
   fprintf(stderr,"%s: BUG: No background definition?\n",MyName);
 #endif
@@ -252,8 +300,10 @@ Pixel buttonShadow(button_info *b)
   if(b->flags&b_Back)
     return b->sc;
   while((b=b->parent))
+  {
     if(b->c->flags&b_Back)
       return b->c->sc;
+  }
 #ifdef DEBUG
   fprintf(stderr,"%s: BUG: No background definition?\n",MyName);
 #endif
@@ -267,18 +317,20 @@ Pixel buttonShadow(button_info *b)
 byte buttonSwallow(button_info *b)
 {
   byte s=0,t=0;
-  if(b->flags&b_Swallow)
-    {
-      s=b->swallow;
-      t=b->swallow_mask;
-    }
+  if(b->flags & (b_Swallow | b_Panel))
+  {
+    s=b->swallow;
+    t=b->swallow_mask;
+  }
   while((b=b->parent))
-    if(b->c->flags&b_Swallow)
-      {
-	s&=~(b->c->swallow_mask&~t);
-	s|=(b->c->swallow&b->c->swallow_mask&~t);
-	t|=b->c->swallow_mask;
-      }
+  {
+    if(b->c->flags & (b_Swallow | b_Panel))
+    {
+      s&=~(b->c->swallow_mask&~t);
+      s|=(b->c->swallow&b->c->swallow_mask&~t);
+      t|=b->c->swallow_mask;
+    }
+  }
   return s;
 }
 
@@ -290,17 +342,19 @@ byte buttonJustify(button_info *b)
 {
   byte j=1,i=0;
   if(b->flags&b_Justify)
-    {
-      i=b->justify_mask;
-      j=b->justify;
-    }
+  {
+    i=b->justify_mask;
+    j=b->justify;
+  }
   while((b=b->parent))
+  {
     if(b->c->flags&b_Justify)
-      {
-	j&=~(b->c->justify_mask&~i);
-	j|=(b->c->justify&b->c->justify_mask&~i);
-	i|=b->c->justify_mask;
-      }
+    {
+      j&=~(b->c->justify_mask&~i);
+      j|=(b->c->justify&b->c->justify_mask&~i);
+      i|=b->c->justify_mask;
+    }
+  }
   return j;
 }
 
@@ -317,26 +371,26 @@ void alloc_buttonlist(button_info *ub,int num)
   int i,old;
 
   if(num>=ub->c->allocated_buttons)
+  {
+    old=ub->c->allocated_buttons;
+    if(num<old || old+32<old)
     {
-      old=ub->c->allocated_buttons;
-      if(num<old || old+32<old)
-	{
-	  fprintf(stderr,"%s: Too many buttons, integer overflow\n",MyName);
-	  exit(1);
-	}
-      while(ub->c->allocated_buttons<=num)
-        ub->c->allocated_buttons+=32;
-      bb=(button_info**)
-	mymalloc(ub->c->allocated_buttons*sizeof(button_info*));
-      for(i=old;i<ub->c->allocated_buttons;i++)
-	bb[i]=NULL;
-      if(ub->c->buttons)
-	{
-	  for(i=0;i<old;i++) bb[i]=ub->c->buttons[i];
-          free(ub->c->buttons);
-	}
-      ub->c->buttons=bb;
+      fprintf(stderr,"%s: Too many buttons, integer overflow\n",MyName);
+      exit(1);
     }
+    while(ub->c->allocated_buttons<=num)
+      ub->c->allocated_buttons+=32;
+    bb=(button_info**)
+      mymalloc(ub->c->allocated_buttons*sizeof(button_info*));
+    for(i=old;i<ub->c->allocated_buttons;i++)
+      bb[i]=NULL;
+    if(ub->c->buttons)
+    {
+      for(i=0;i<old;i++) bb[i]=ub->c->buttons[i];
+      free(ub->c->buttons);
+    }
+    ub->c->buttons=bb;
+  }
 }
 
 /**
@@ -350,10 +404,10 @@ button_info *alloc_button(button_info *ub,int num)
   if(num>=ub->c->allocated_buttons)
     alloc_buttonlist(ub,num);
   if(ub->c->buttons[num])
-    {
-      fprintf(stderr,"%s: Allocated button twice, report bug twice\n",MyName);
-      exit(2);
-    }
+  {
+    fprintf(stderr,"%s: Allocated button twice, report bug twice\n",MyName);
+    exit(2);
+  }
 
   b=(button_info*)mymalloc(sizeof(button_info));
   ub->c->buttons[num]=b;
@@ -374,6 +428,12 @@ button_info *alloc_button(button_info *ub,int num)
   b->h=1;
   b->bw=1;
 
+  if(b->parent != NULL)
+  {
+    if (b->parent->c->flags & b_Colorset)
+      b->flags |= b_ColorsetParent;
+  }
+
   return(b);
 }
 
@@ -384,31 +444,25 @@ button_info *alloc_button(button_info *ub,int num)
 void MakeContainer(button_info *b)
 {
   b->c=(container_info*)mymalloc(sizeof(container_info));
+  memset((void *)b->c, 0, sizeof(container_info));
   b->flags|=b_Container;
-  b->c->buttons=NULL;
-  b->c->num_buttons=0;
-  b->c->num_rows=0;
-  b->c->num_columns=0;
-  b->c->allocated_buttons=0;
-  b->c->xpos=0;
-  b->c->ypos=0;
   if(b->parent != NULL)
-    {
-      if (b->parent->c->flags&b_IconBack || b->parent->c->flags&b_IconParent)
-	b->c->flags=b_IconParent;
-      else
-	b->c->flags=0;
-    }
+  {
+    if (b->parent->c->flags & b_IconBack || b->parent->c->flags & b_IconParent)
+      b->c->flags = b_IconParent;
+    if (b->parent->c->flags & b_Colorset)
+      b->c->flags = b_ColorsetParent;
+  }
   else /* This applies to the UberButton */
-    {
-      b->c->flags=b_Font|b_Padding|b_Frame|b_Back|b_Fore;
-      b->c->font_string=strdup("fixed");
-      b->c->xpad=2;
-      b->c->ypad=4;
-      b->c->back=strdup("#908090");
-      b->c->fore=strdup("black");
-      b->c->framew=2;
-    }
+  {
+    b->c->flags=b_Font|b_Padding|b_Frame|b_Back|b_Fore;
+    b->c->font_string=strdup("fixed");
+    b->c->xpad=2;
+    b->c->ypad=4;
+    b->c->back=strdup("rgb:90/80/90");
+    b->c->fore=strdup("black");
+    b->c->framew=2;
+  }
 
 }
 
@@ -423,17 +477,17 @@ void NumberButtons(button_info *b)
   int i=-1;
   while(++i<b->c->num_buttons)
     if(b->c->buttons[i])
-      {
-	b->c->buttons[i]->n=i;
-	if(b->c->buttons[i]->flags&b_Container)
-	  NumberButtons(b->c->buttons[i]);
-      }
+    {
+      b->c->buttons[i]->n=i;
+      if(b->c->buttons[i]->flags&b_Container)
+	NumberButtons(b->c->buttons[i]);
+    }
 }
 
 /**
 *** PlaceAndExpandButton()
 *** Places a button in it's container and claims all needed slots.
- **/
+**/
 char PlaceAndExpandButton(int x, int y, button_info *b, button_info *ub)
 {
   int i,j,k;
@@ -441,49 +495,49 @@ char PlaceAndExpandButton(int x, int y, button_info *b, button_info *ub)
 
   i = x+y*c->num_columns;
   if (x>=c->num_columns || x<0)
+  {
+    fprintf(stderr,"%s: Button out of horizontal range. Quitting.\n",MyName);
+    fprintf(stderr,"Button=%d num_columns=%d BPosX=%d\n",
+	    i,c->num_columns,b->BPosX);
+    exit(1);
+  }
+  if (y>=c->num_rows || y<0)
+  {
+    if (b->flags&b_PosFixed || !(ub->c->flags&b_SizeSmart) || y<0)
     {
-      fprintf(stderr,"%s: Button out of horizontal range. Quitting.\n",MyName);
-      fprintf(stderr,"Button=%d num_columns=%d BPosX=%d\n",
-	      i,c->num_columns,b->BPosX);
+      fprintf(stderr,"%s: Button out of vertical range. Quitting.\n",
+	      MyName);
+      fprintf(stderr,"Button=%d num_rows=%d BPosY=%d\n",
+	      i,c->num_rows,b->BPosY);
       exit(1);
     }
-  if (y>=c->num_rows || y<0)
+    c->num_rows=y+b->BHeight;
+    c->num_buttons=c->num_columns*c->num_rows;
+    alloc_buttonlist(ub,c->num_buttons);
+  }
+  if(x+b->BWidth>c->num_columns)
+  {
+    fprintf(stderr,"%s: Button too wide. giving up\n",MyName);
+    fprintf(stderr,"Button=%d num_columns=%d bwidth=%d w=%d\n",
+	    i,c->num_columns,b->BWidth,x);
+    b->BWidth = c->num_columns-x;
+  }
+  if(y+b->BHeight>c->num_rows)
+  {
+    if (c->flags&b_SizeSmart)
     {
-      if (b->flags&b_PosFixed || !(ub->c->flags&b_SizeSmart) || y<0)
-	{
-	  fprintf(stderr,"%s: Button out of vertical range. Quitting.\n",
-		  MyName);
-	  fprintf(stderr,"Button=%d num_rows=%d BPosY=%d\n",
-		  i,c->num_rows,b->BPosY);
-	  exit(1);
-	}
       c->num_rows=y+b->BHeight;
       c->num_buttons=c->num_columns*c->num_rows;
       alloc_buttonlist(ub,c->num_buttons);
     }
-  if(x+b->BWidth>c->num_columns)
+    else
     {
-      fprintf(stderr,"%s: Button too wide. giving up\n",MyName);
-      fprintf(stderr,"Button=%d num_columns=%d bwidth=%d w=%d\n",
-	      i,c->num_columns,b->BWidth,x);
-      b->BWidth = c->num_columns-x;
-    }
-  if(y+b->BHeight>c->num_rows)
-    {
-      if (c->flags&b_SizeSmart)
-	{
-	  c->num_rows=y+b->BHeight;
-	  c->num_buttons=c->num_columns*c->num_rows;
-	  alloc_buttonlist(ub,c->num_buttons);
-	}
-      else
-	{
-	  fprintf(stderr,"%s: Button too tall. Giving up\n",MyName);
-	  fprintf(stderr,"Button=%d num_rows=%d bheight=%d h=%d\n",
-		  i,c->num_rows,b->BHeight,y);
-	  b->BHeight = c->num_rows-y;
-	}
+      fprintf(stderr,"%s: Button too tall. Giving up\n",MyName);
+      fprintf(stderr,"Button=%d num_rows=%d bheight=%d h=%d\n",
+	      i,c->num_rows,b->BHeight,y);
+      b->BHeight = c->num_rows-y;
     }
+  }
 
   /* check if buttons are free */
   for(k=0;k<b->BHeight;k++)
@@ -502,30 +556,34 @@ char PlaceAndExpandButton(int x, int y, button_info *b, button_info *ub)
 /**
 *** ShrinkButton()
 *** Frees all but the upper left slot a button uses in it's container.
- **/
+**/
 void ShrinkButton(button_info *b, container_info *c)
 {
   int i,j,k,l;
 
   if (!b)
-    {
-      fprintf(stderr,"error: shrink1: button is empty but shouldn't\n");
-      exit(1);
-    }
+  {
+    fprintf(stderr,"error: shrink1: button is empty but shouldn't\n");
+    exit(1);
+  }
   i = b->BPosX+b->BPosY*c->num_columns;
   /* free all buttons but the upper left corner */
   for(k=0;k<b->BHeight;k++)
+  {
     for(j=0;j<b->BWidth;j++)
+    {
       if(j||k)
+      {
+	l = i+j+k*c->num_columns;
+	if (c->buttons[l] != b)
 	{
-	  l = i+j+k*c->num_columns;
-	  if (c->buttons[l] != b)
-	    {
-	      fprintf(stderr,"error: shrink2: button was stolen\n");
-	      exit(1);
-	    }
-	  c->buttons[l] = NULL;
+	  fprintf(stderr,"error: shrink2: button was stolen\n");
+	  exit(1);
 	}
+	c->buttons[l] = NULL;
+      }
+    }
+  }
 }
 
 /**
@@ -545,10 +603,10 @@ void ShuffleButtons(button_info *ub)
   num_items = c->num_buttons;
   local_buttons=(button_info**)mymalloc(sizeof(button_info)*num_items);
   for(i=0;i<num_items;i++)
-    {
-      local_buttons[i] = c->buttons[i];
-      c->buttons[i] = NULL;
-    }
+  {
+    local_buttons[i] = c->buttons[i];
+    c->buttons[i] = NULL;
+  }
 
   /* Allow for multi-width/height buttons */
   actual_buttons_used = 0;
@@ -556,42 +614,44 @@ void ShuffleButtons(button_info *ub)
     actual_buttons_used+=local_buttons[i]->BWidth*local_buttons[i]->BHeight;
 
   if (!(c->flags&b_SizeFixed)||!(c->num_rows)||!(c->num_columns))
+  {
+    /* Size and create the window */
+    if(c->num_rows==0 && c->num_columns==0)
+      c->num_rows=2;
+    if(c->num_columns==0)
+      c->num_columns=1+(actual_buttons_used-1)/c->num_rows;
+    if(c->num_rows==0)
+      c->num_rows=1+(actual_buttons_used-1)/c->num_columns;
+    while(c->num_rows * c->num_columns < actual_buttons_used)
+      c->num_columns++;
+    if (!(c->flags&b_SizeFixed))
     {
-      /* Size and create the window */
-      if(c->num_rows==0 && c->num_columns==0)
-	c->num_rows=2;
-      if(c->num_columns==0)
-	c->num_columns=1+(actual_buttons_used-1)/c->num_rows;
-      if(c->num_rows==0)
-	c->num_rows=1+(actual_buttons_used-1)/c->num_columns;
-      while(c->num_rows * c->num_columns < actual_buttons_used)
-	c->num_columns++;
-      if (!(c->flags&b_SizeFixed))
-	{
-	  while(c->num_rows*c->num_columns >=
-		actual_buttons_used + c->num_columns)
-	    c->num_rows--;
-	}
+      while(c->num_rows*c->num_columns >=
+	    actual_buttons_used + c->num_columns)
+	c->num_rows--;
     }
+  }
 
   if (c->flags&b_SizeSmart)
+  {
+    /* Set rows/columns to at least the height/width of largest button */
+    for(i=0;i<num_items;i++)
     {
-      /* Set rows/columns to at least the height/width of largest button */
-      for(i=0;i<num_items;i++)
-	{
-	  b=local_buttons[i];
-          if (c->num_rows<b->BHeight) c->num_rows=b->BHeight;
-	  if (c->num_columns<b->BWidth) c->num_columns=b->BWidth;
-          if (b->flags&b_PosFixed && c->num_columns<b->BWidth+b->BPosX)
-	    c->num_columns=b->BWidth+b->BPosX;
-          if (b->flags&b_PosFixed && c->num_columns<b->BWidth-b->BPosX)
-	    c->num_columns=b->BWidth-b->BPosX;
-          if (b->flags&b_PosFixed && c->num_rows<b->BHeight+b->BPosY)
-	    c->num_rows=b->BHeight+b->BPosY;
-          if (b->flags&b_PosFixed && c->num_rows<b->BHeight-b->BPosY)
-	    c->num_rows=b->BHeight-b->BPosY;
-	}
+      b=local_buttons[i];
+      if (c->num_rows<b->BHeight)
+	c->num_rows=b->BHeight;
+      if (c->num_columns<b->BWidth)
+	c->num_columns=b->BWidth;
+      if (b->flags&b_PosFixed && c->num_columns<b->BWidth+b->BPosX)
+	c->num_columns=b->BWidth+b->BPosX;
+      if (b->flags&b_PosFixed && c->num_columns<b->BWidth-b->BPosX)
+	c->num_columns=b->BWidth-b->BPosX;
+      if (b->flags&b_PosFixed && c->num_rows<b->BHeight+b->BPosY)
+	c->num_rows=b->BHeight+b->BPosY;
+      if (b->flags&b_PosFixed && c->num_rows<b->BHeight-b->BPosY)
+	c->num_rows=b->BHeight-b->BPosY;
     }
+  }
 
   /* this was buggy before */
   c->num_buttons = c->num_rows*c->num_columns;
@@ -599,59 +659,59 @@ void ShuffleButtons(button_info *ub)
 
   /* Shuffle subcontainers */
   for(i=0;i<num_items;i++)
-    {
-      b=local_buttons[i];
-      /* Shuffle subcontainers recursively */
-      if(b && b->flags&b_Container)
-	ShuffleButtons(b);
-    }
+  {
+    b=local_buttons[i];
+    /* Shuffle subcontainers recursively */
+    if(b && b->flags&b_Container)
+      ShuffleButtons(b);
+  }
 
   /* Place fixed buttons as given in BPosX and BPosY */
   for(i=0;i<num_items;i++)
+  {
+    b=local_buttons[i];
+    if (!(b->flags&b_PosFixed)) continue;
+    /* recalculate position for negative offsets */
+    if (b->BPosX<0) b->BPosX=b->BPosX+c->num_columns-b->BWidth+1;
+    if (b->BPosY<0) b->BPosY=b->BPosY+c->num_rows-b->BHeight+1;
+    /* Move button if position given by user */
+    if (PlaceAndExpandButton(b->BPosX,b->BPosY,b,ub))
     {
-      b=local_buttons[i];
-      if (!(b->flags&b_PosFixed)) continue;
-      /* recalculate position for negative offsets */
-      if (b->BPosX<0) b->BPosX=b->BPosX+c->num_columns-b->BWidth+1;
-      if (b->BPosY<0) b->BPosY=b->BPosY+c->num_rows-b->BHeight+1;
-      /* Move button if position given by user */
-      if (PlaceAndExpandButton(b->BPosX,b->BPosY,b,ub))
-	{
-	  fprintf(stderr, "%s: Overlapping fixed buttons. Quitting.\n",MyName);
-	  fprintf(stderr, "Button=%d, x=%d, y=%d\n", i,b->BPosX,b->BPosY);
-	  exit(1);
-	}
+      fprintf(stderr, "%s: Overlapping fixed buttons. Quitting.\n",MyName);
+      fprintf(stderr, "Button=%d, x=%d, y=%d\n", i,b->BPosX,b->BPosY);
+      exit(1);
     }
+  }
 
   /* place floating buttons dynamically */
   next_button_x = next_button_y = 0;
   for(i=0;i<num_items;i++)
-    {
-      b=local_buttons[i];
-      if (b->flags&b_PosFixed) continue;
+  {
+    b=local_buttons[i];
+    if (b->flags&b_PosFixed) continue;
 
-      if (next_button_x+b->BWidth>c->num_columns)
-	{
-	  next_button_y++;
-	  next_button_x=0;
-        }
-      /* Search for next free position to accomodate button */
-      while (PlaceAndExpandButton(next_button_x,next_button_y,b,ub))
-	{
-	  next_button_x++;
-	  if (next_button_x+b->BWidth>c->num_columns)
-	    {
-	      next_button_y++;
-	      next_button_x=0;
-	      if (next_button_y>=c->num_rows)
-		{
-		  /* could not place button */
-		  fprintf(stderr,"%s: Button confusion! Quitting\n", MyName);
-		  exit(1);
-		}
-	    }
-	}
+    if (next_button_x+b->BWidth>c->num_columns)
+    {
+      next_button_y++;
+      next_button_x=0;
     }
+    /* Search for next free position to accomodate button */
+    while (PlaceAndExpandButton(next_button_x,next_button_y,b,ub))
+    {
+      next_button_x++;
+      if (next_button_x+b->BWidth>c->num_columns)
+      {
+	next_button_y++;
+	next_button_x=0;
+	if (next_button_y>=c->num_rows)
+	{
+	  /* could not place button */
+	  fprintf(stderr,"%s: Button confusion! Quitting\n", MyName);
+	  exit(1);
+	}
+      }
+    }
+  }
 
   /* shrink buttons in Container */
   for(i=0;i<num_items;i++)
@@ -677,35 +737,35 @@ button_info *NextButton(button_info **ub,button_info **b,int *i,int all)
     (*i)++;
   /* End of contained buttons */
   if((*i)>=(*ub)->c->num_buttons)
+  {
+    *b=*ub;
+    *ub=(*b)->parent;
+    /* End of the world as we know it */
+    if(!(*ub))
     {
-      *b=*ub;
-      *ub=(*b)->parent;
-      /* End of the world as we know it */
-      if(!(*ub))
-	{
-	  *b=NULL;
-	  return *b;
-	}
-      *i=(*b)->n;
-      if((*i)>=(*ub)->c->num_buttons)
-	{
-	  fprintf(stderr,"%s: BUG: Couldn't return to uberbutton\n",MyName);
-	  exit(2);
-	}
-      NextButton(ub,b,i,all);
+      *b=NULL;
       return *b;
     }
+    *i=(*b)->n;
+    if((*i)>=(*ub)->c->num_buttons)
+    {
+      fprintf(stderr,"%s: BUG: Couldn't return to uberbutton\n",MyName);
+      exit(2);
+    }
+    NextButton(ub,b,i,all);
+    return *b;
+  }
   *b=(*ub)->c->buttons[*i];
 
   /* Found new container */
   if((*b)->flags & b_Container)
-    {
-      *i=-1;
-      *ub=*b;
-      if(!all)
-	NextButton(ub,b,i,all);
-      return *b;
-    }
+  {
+    *i=-1;
+    *ub=*b;
+    if(!all)
+      NextButton(ub,b,i,all);
+    return *b;
+  }
   return *b;
 }
 
@@ -727,14 +787,16 @@ int button_belongs_to(button_info *ub,int button)
   yy=button/ub->c->num_columns;
   xx=button%ub->c->num_columns;
   for(y=yy;y>=0;y--)
+  {
     for(x=xx;x>=0;x--)
+    {
+      b=ub->c->buttons[x+y*ub->c->num_columns];
+      if(b && (x+b->BWidth > xx) && (y+b->BHeight > yy))
       {
-	b=ub->c->buttons[x+y*ub->c->num_columns];
-	if(b && (x+b->BWidth > xx) && (y+b->BHeight > yy))
-	  {
-	    return x+y*ub->c->num_columns;
-	  }
+	return x+y*ub->c->num_columns;
       }
+    }
+  }
   return -1;
 }
 
@@ -745,21 +807,27 @@ int button_belongs_to(button_info *ub,int button)
 button_info *select_button(button_info *ub,int x,int y)
 {
   int i;
+  int row;
+  int column;
   button_info *b;
-  if(!(ub->flags&b_Container))
+
+  if (!(ub->flags&b_Container))
     return ub;
 
-  x-=buttonXPad(ub)+buttonFrame(ub);
-  y-=buttonYPad(ub)+buttonFrame(ub);
+  x -= buttonXPad(ub) + buttonFrame(ub);
+  y -= buttonYPad(ub) + buttonFrame(ub);
 
-  if(x >= ub->c->ButtonWidth * ub->c->num_columns || x<0 ||
-     y >= ub->c->ButtonHeight * ub->c->num_rows || y<0)
+  if(x >= ub->c->width || x < 0 || y >= ub->c->height || y < 0)
     return ub;
 
-  i=x/ub->c->ButtonWidth + (y/ub->c->ButtonHeight)*ub->c->num_columns;
-  i=button_belongs_to(ub,i);
-  if(i==-1)return ub;
-  b=ub->c->buttons[i];
-  return select_button(b,x-(i%ub->c->num_columns)*ub->c->ButtonWidth,
-		       y-(i/ub->c->num_columns)*ub->c->ButtonHeight);
+  column = x * ub->c->num_columns / ub->c->width;
+  row = y * ub->c->num_rows / ub->c->height;
+  i = button_belongs_to(ub, column + row * ub->c->num_columns);
+  if (i == -1)
+    return ub;
+  b = ub->c->buttons[i];
+
+  return select_button(
+      b, x + ub->c->xpos - buttonXPos(b, i),
+      y + ub->c->ypos - buttonYPos(b, i));
 }
