@@ -1,6 +1,6 @@
 /*
-   Fvwmbuttons, copyright 1996, Jarl Totland
-
+ * Fvwmbuttons, copyright 1996, Jarl Totland
+ *
  * This module, and the entire GoodStuff program, and the concept for
  * interfacing this module to the Window Manager, are all original work
  * by Robert Nation
@@ -9,8 +9,8 @@
  * are provided or implied in any way whatsoever. Use this program at your
  * own risk. Permission to use this program for any purpose is given,
  * as long as the copyright is kept intact.
-
-*/
+ *
+ */
 
 /* This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,7 @@
 #include <X11/Xatom.h>
 #include <X11/Intrinsic.h>
 
+#include "libs/Colorset.h"
 #include "FvwmButtons.h"
 #include "misc.h" /* ConstrainSize() */
 #include "icons.h" /* ConfigureIconWindow() */
@@ -64,29 +65,30 @@
 void RelieveButton(Window wn,int width,int x,int y,int w,int h,Pixel relief,
 		   Pixel shadow,int rev)
 {
-  unsigned long gcm=0;
   XGCValues gcv;
   GC swapGC, reliefGC, shadowGC;
 
   if(!width)
     return;
 
-  gcm=GCForeground;
   gcv.foreground=relief;
-  XChangeGC(Dpy,NormalGC,gcm,&gcv);
+  XChangeGC(Dpy,NormalGC,GCForeground,&gcv);
   reliefGC=NormalGC;
 
-  gcm=GCForeground;
   gcv.foreground=shadow;
-  XChangeGC(Dpy,ShadowGC,gcm,&gcv);
+  XChangeGC(Dpy,ShadowGC,GCForeground,&gcv);
   shadowGC=ShadowGC;
 
-  if(width<0) {
+  if(width<0)
+  {
     width=-width;
-    swapGC=reliefGC;reliefGC=shadowGC;shadowGC=swapGC;
+    rev = !rev;
   }
-  if(rev) {
-    swapGC=reliefGC;reliefGC=shadowGC;shadowGC=swapGC;
+  if(rev)
+  {
+    swapGC=reliefGC;
+    reliefGC=shadowGC;
+    shadowGC=swapGC;
   }
 
   RelieveRectangle(Dpy,wn,x,y,w-1,h-1,reliefGC,shadowGC,width);
@@ -99,22 +101,22 @@ void RelieveButton(Window wn,int width,int x,int y,int w,int h,Pixel relief,
 void MakeButton(button_info *b)
 {
   /* This is resposible for drawing the contents of a button, placing the
-     icon and/or swallowed item in the correct position inside potential
-     padding or frame.
-  */
+   * icon and/or swallowed item in the correct position inside potential
+   * padding or frame.
+   */
   int ih,iw,ix,iy;
   XFontStruct *font;
 
   if(!b)
-    {
-      fprintf(stderr,"%s: BUG: DrawButton called with NULL pointer\n",MyName);
-      exit(2);
-    }
+  {
+    fprintf(stderr,"%s: BUG: MakeButton called with NULL pointer\n",MyName);
+    exit(2);
+  }
   if(b->flags&b_Container)
-    {
-      fprintf(stderr,"%s: BUG: DrawButton called with container\n",MyName);
-      exit(2);
-    }
+  {
+    fprintf(stderr,"%s: BUG: MakeButton called with container\n",MyName);
+    exit(2);
+  }
 
   if(!(b->flags&b_Icon) && (buttonSwallowCount(b)<3))
     return;
@@ -123,6 +125,10 @@ void MakeButton(button_info *b)
   if (b->parent->c->flags&b_IconBack || b->parent->c->flags&b_IconParent)
     b->flags|=b_IconParent;
 
+  /* Check if parent container has a colorset definition as background */
+  if (b->parent->c->flags&b_Colorset)
+    b->flags|=b_ColorsetParent;
+
   font = buttonFont(b);
 
   GetInternalSize(b,&ix,&iy,&iw,&ih);
@@ -135,39 +141,39 @@ void MakeButton(button_info *b)
     ConfigureIconWindow(b);
 
   /* For now, hardcoded window centered, title bottom centered, below window */
-  else if(buttonSwallowCount(b)==3)
+  else if(buttonSwallowCount(b)==3 && (b->flags & b_Swallow))
+  {
+    long supplied;
+    if(!b->IconWin)
     {
-      long supplied;
-      if(!b->IconWin)
-	{
-	  fprintf(stderr,"%s: BUG: Swallowed window has no IconWin\n",MyName);
-	  exit(2);
-	}
-
-      if(b->flags&b_Title && font && !(buttonJustify(b)&b_Horizontal))
-	ih -= font->ascent+font->descent;
-
-      b->icon_w=iw;
-      b->icon_h=ih;
-
-      if(iw>0 && ih>0)
-	{
-	  if(!(buttonSwallow(b)&b_NoHints))
-	    {
-	      if(!XGetWMNormalHints(Dpy,b->IconWin,b->hints,&supplied))
-		b->hints->flags=0;
-	      ConstrainSize(b->hints,&b->icon_w,&b->icon_h);
-	    }
-	  if (b->flags & b_Right)
-	    ix += iw-b->icon_w;
-	  else if (!(b->flags & b_Left))
-	    ix += (iw-b->icon_w)/2;
-	  XMoveResizeWindow(Dpy,b->IconWin,ix,iy+(ih-b->icon_h)/2,
-			    b->icon_w,b->icon_h);
-	}
-      else
-	XMoveWindow(Dpy,b->IconWin,2000,2000);
+      fprintf(stderr,"%s: BUG: Swallowed window has no IconWin\n",MyName);
+      exit(2);
     }
+
+    if(b->flags&b_Title && font && !(buttonJustify(b)&b_Horizontal))
+      ih -= font->ascent+font->descent;
+
+    b->icon_w=iw;
+    b->icon_h=ih;
+
+    if(iw>0 && ih>0)
+    {
+      if(!(buttonSwallow(b)&b_NoHints))
+      {
+	if(!XGetWMNormalHints(Dpy,b->IconWin,b->hints,&supplied))
+	  b->hints->flags=0;
+	ConstrainSize(b->hints,&b->icon_w,&b->icon_h);
+      }
+      if (b->flags & b_Right)
+	ix += iw-b->icon_w;
+      else if (!(b->flags & b_Left))
+	ix += (iw-b->icon_w)/2;
+      XMoveResizeWindow(Dpy,b->IconWin,ix,iy+(ih-b->icon_h)/2,
+			b->icon_w,b->icon_h);
+    }
+    else
+      XMoveWindow(Dpy,b->IconWin,2000,2000);
+  }
 }
 
 /**
@@ -180,12 +186,14 @@ void RedrawButton(button_info *b,int clean)
   int i,j,k,BH,BW;
   int f,x,y,px,py;
   int ix,iy,iw,ih;
-  XFontStruct *font=buttonFont(b);
+  XFontStruct *font = buttonFont(b);
 #ifdef I18N_MB
+  /*
+    there seems to be no I18N patch here
   XFontSet fontset = buttonFontSet(b);
+  */
 #endif
   XGCValues gcv;
-  unsigned long gcm=0;
   int rev=0;
 
   BW = buttonWidth(b);
@@ -195,25 +203,29 @@ void RedrawButton(button_info *b,int clean)
 
   /* This probably isn't the place for this, but it seems to work here and not
      elsewhere, so... */
-  if((buttonSwallowCount(b)==3) && b->IconWin!=None)
+  if((b->flags & b_Swallow) && (buttonSwallowCount(b)==3) && b->IconWin!=None)
     XSetWindowBorderWidth(Dpy,b->IconWin,0);
 
   /* ----------------------------------------------------------------------- */
 
-  if(b->flags&b_Hangon || b==CurrentButton)  /* Hanging or held down by user */
+  if((b->flags & b_Hangon && b->flags & b_Swallow) || b == CurrentButton ||
+     (b->flags & b_Panel && b->newflags.panel_mapped))
+  {
+    /* Hanging swallow or held down by user or mappen panel */
     rev=1;
+  }
   if(b->flags&b_Action) /* If this is a Desk button that takes you to here.. */
+  {
+    int n=0;
+    while(n<4 && (!b->action[n] || strncasecmp(b->action[n],"Desk",4)))
+      n++;
+    if(n<4)
     {
-      int n=0;
-      while(n<4 && (!b->action[n] || strncasecmp(b->action[n],"Desk",4)))
-	n++;
-      if(n<4)
-	{
-	  k=sscanf(&b->action[n][4],"%d%d",&i,&j);
-	  if(k==2 && i==0 && j==new_desk)
-	    rev=1;
-	}
+      k=sscanf(&b->action[n][4],"%d%d",&i,&j);
+      if(k==2 && i==0 && j==new_desk)
+	rev=1;
     }
+  }
 
   RelieveButton(MyWindow,f,x,y,BW,BH,buttonHilite(b),buttonShadow(b),rev);
 
@@ -222,41 +234,64 @@ void RedrawButton(button_info *b,int clean)
   f=abs(f);
 
   if(clean && BW>2*f && BH>2*f)
+  {
+    gcv.foreground=buttonBack(b);
+    XChangeGC(Dpy,NormalGC,GCForeground,&gcv);
+
+    if(b->flags&b_Container)
     {
-      gcm = GCForeground;
-      gcv.foreground=buttonBack(b);
-      XChangeGC(Dpy,NormalGC,gcm,&gcv);
+      if (b->c->flags & b_Colorset)
+      {
+	SetRectangleBackground(
+	  Dpy, MyWindow, ix, iy, iw, ih,
+	  &Colorset[b->c->colorset % nColorsets], Pdepth, NormalGC);
+      }
+      else
+      {
+	int x1 = x + f;
+	int y1 = y + f;
+	int w1 = px;
+	int h1 = py;
+	int w2 = w1;
+	int h2 = h1;
+	int w = BW - 2 * f;
+	int h = BH - 2 * f;
 
-      if(b->flags&b_Container)
-	{
-	  int x1=x+f,y1=y+f;
-	  int w1=px,h1=py,w2=w1,h2=h1;
-	  int w=BW-2*f,h=BH-2*f;
-	  w2+=iw - b->c->num_columns*b->c->ButtonWidth;
-	  h2+=ih - b->c->num_rows*b->c->ButtonHeight;
+	w2 += iw - b->c->width;
+	h2 += ih - b->c->height;
 
-	  if(w1)
-	    XFillRectangle(Dpy,MyWindow,NormalGC,x1,y1,w1,h);
-	  if(w2)
-	    XFillRectangle(Dpy,MyWindow,NormalGC,x1+w-w2,y1,w2,h);
-	  if(h1)
-	    XFillRectangle(Dpy,MyWindow,NormalGC,x1,y1,w,h1);
-	  if(h2)
-	    XFillRectangle(Dpy,MyWindow,NormalGC,x1,y1+h-h2,w,h2);
-	}
-      else if(!(b->flags&b_IconBack) && !(b->flags&b_IconParent) &&
-	      !(b->flags&b_Swallow))
-	XFillRectangle(Dpy,MyWindow,NormalGC,x+f,y+f,BW-2*f,BH-2*f);
+	if(w1)
+	  XFillRectangle(Dpy,MyWindow,NormalGC,x1,y1,w1,h);
+	if(w2)
+	  XFillRectangle(Dpy,MyWindow,NormalGC,x1+w-w2,y1,w2,h);
+	if(h1)
+	  XFillRectangle(Dpy,MyWindow,NormalGC,x1,y1,w,h1);
+	if(h2)
+	  XFillRectangle(Dpy,MyWindow,NormalGC,x1,y1+h-h2,w,h2);
+      }
     }
+    else if (b->flags & b_Colorset)
+    {
+      SetRectangleBackground(
+	Dpy, MyWindow, ix, iy, iw, ih, &Colorset[b->colorset % nColorsets],
+	Pdepth, NormalGC);
+    }
+    else if (!(b->flags&b_IconBack) && !(b->flags&b_IconParent) &&
+	     !(b->flags&b_Swallow) && !(b->flags&b_ColorsetParent))
+    {
+      XFillRectangle(Dpy,MyWindow,NormalGC,x+f,y+f,BW-2*f,BH-2*f);
+    }
+  }
 
   /* ----------------------------------------------------------------------- */
 
-  if(b->flags&b_Title) {
-    if (font) {
-      gcm = GCForeground | GCFont;
+  if(b->flags&b_Title)
+  {
+    if (font)
+    {
       gcv.foreground=buttonFore(b);
       gcv.font = font->fid;
-      XChangeGC(Dpy,NormalGC,gcm,&gcv);
+      XChangeGC(Dpy,NormalGC,GCForeground | GCFont,&gcv);
       DrawTitle(b,MyWindow,NormalGC);
     }
   }
@@ -290,36 +325,36 @@ void DrawTitle(button_info *b,Window win,GC gc)
 
   /* If a title is to be shown, truncate it until it fits */
   if(justify&b_Horizontal && !(b->flags & b_Right))
+  {
+    if(b->flags&b_Icon)
     {
-      if(b->flags&b_Icon)
-	{
-	  ix+=b->icon->width+buttonXPad(b);
-	  iw-=b->icon->width+buttonXPad(b);
-	}
-      else if (buttonSwallowCount(b)==3)
-	{
-	  ix+=b->icon_w+buttonXPad(b);
-	  iw-=b->icon_w+buttonXPad(b);
-	}
+      ix+=b->icon->width+buttonXPad(b);
+      iw-=b->icon->width+buttonXPad(b);
     }
+    else if ((b->flags & b_Swallow) && buttonSwallowCount(b)==3)
+    {
+      ix += b->icon_w+buttonXPad(b);
+      iw -= b->icon_w+buttonXPad(b);
+    }
+  }
 
-  s=b->title;
-  l=strlen(s);
-  i=XTextWidth(font,s,l);
+  s = b->title;
+  l = strlen(s);
+  i = XTextWidth(font,s,l);
 
   if(i>iw)
+  {
+    if(just==2)
     {
-      if(just==2)
-	{
-	  while(i>iw && *s)
-	    i=XTextWidth(font,++s,--l);
-	}
-      else /* Left or center - cut off its tail */
-	{
-	  while(i>iw && l>0)
-	    i=XTextWidth(font,s,--l);
-	}
+      while(i>iw && *s)
+	i=XTextWidth(font,++s,--l);
     }
+    else /* Left or center - cut off its tail */
+    {
+      while(i>iw && l>0)
+	i=XTextWidth(font,s,--l);
+    }
+  }
   if(just==0 || ((justify&b_Horizontal) && (b->flags&b_Right))) /* Left */
     xpos=ix;
   else if(just==2) /* Right */
@@ -328,22 +363,22 @@ void DrawTitle(button_info *b,Window win,GC gc)
     xpos=ix+(iw-i)/2;
 
   if(*s && l>0 && BH>=font->descent+font->ascent) /* Clip it somehow? */
+  {
+    /* If there is more than the title, put it at the bottom */
+    /* Unless stack flag is set, put it to the right of icon */
+    if((b->flags&b_Icon ||
+	((buttonSwallowCount(b)==3) && (b->flags&b_Swallow))) &&
+       !(justify&b_Horizontal))
     {
-      /* If there is more than the title, put it at the bottom */
-      /* Unless stack flag is set, put it to the right of icon */
-      if((b->flags&b_Icon || (buttonSwallowCount(b)==3)) &&
-	 !(justify&b_Horizontal))
-	{
-	  XDrawString(Dpy,win,gc,xpos,
-		      iy+ih-font->descent,s,l);
-	  /* Shrink the space available for icon/window */
-	  ih-=font->descent+font->ascent;
-	}
-      /* Or else center vertically */
-      else
-	{
-	  XDrawString(Dpy,win,gc,xpos,
-		      iy+(ih+font->ascent-font->descent)/2,s,l);
-	}
+      XDrawString(Dpy, win, gc, xpos, iy+ih-font->descent, s, l);
+      /* Shrink the space available for icon/window */
+      ih-=font->descent+font->ascent;
     }
+    /* Or else center vertically */
+    else
+    {
+      XDrawString(
+	Dpy, win, gc, xpos, iy+(ih+font->ascent-font->descent)/2, s, l);
+    }
+  }
 }
