@@ -1,7 +1,7 @@
-/* $Id: FvwmCommand.c,v 1.5 1999/06/27 14:47:05 domivogt Exp $
+/* $Id: FvwmCommand.c,v 1.8 1999/08/26 01:10:08 domivogt Exp $
  * $Source: /home/cvs/fvwm/fvwm/modules/FvwmCommand/FvwmCommand.c,v $
  *
- * Fvwm2 command input interface.
+ * Fvwm command input interface.
  *
  * Copyright 1998, Toshi Isogai.
  * Use this program at your own risk.
@@ -153,21 +153,25 @@ int main ( int argc, char *argv[]) {
 
 
   if( f_stem == NULL ) {
+    char *dpy_name;
+
+    /* default name */
     home = getenv("HOME");
+    if (!home)  home = "";
     f_stem = safemalloc( strlen(home) + strlen(F_NAME) + MAXHOSTNAME + 4);
     strcpy (f_stem, home);
     if (f_stem[strlen(f_stem)-1] != '/') {
       strcat (f_stem, "/");
     }
     strcat (f_stem, F_NAME);
+
     /* Make it unique */
-    gethostname(hostname,32);
-    strcpy( client, getenv("DISPLAY") );
-    if (!client[0]  ||  ':' == client[0])
-    {
-      sprintf( client, "%s%s", hostname, client );
-    }
     strcat (f_stem, "-");
+    gethostname(hostname,32);
+    dpy_name = getenv("DISPLAY");
+    if (!dpy_name)  dpy_name = ":0";
+    if (!dpy_name[0]  ||  ':' == dpy_name[0])
+      strcat( f_stem, hostname );  /* Put hostname before dpy if not there */
     strcat (f_stem, client);
   }
 
@@ -184,7 +188,7 @@ int main ( int argc, char *argv[]) {
 
   if ((Frun = fopen (Fr_name,"r" )) !=NULL) {
     if (fgets (cmd, 20, Frun) != NULL) {
-      fprintf (stderr, "\nFvwmCommand lock file  %sR is detected. "
+      fprintf (stderr, "\nFvwmCommand lock file %sR is detected. "
 	       "This may indicate another FvwmCommand is running. "
 	       "It appears to be running under process ID:\n%s\n",
 	       f_stem, cmd );
@@ -395,7 +399,7 @@ void receive () {
  *******************************/
 void usage(void) {
   fprintf (stderr, "Usage: %s [OPTION] [COMMAND]...\n", MYNAME);
-  fprintf (stderr, "Send commands to fvwm2 via %sS\n\n", MYNAME);
+  fprintf (stderr, "Send commands to fvwm via %sS\n\n", MYNAME);
   fprintf (stderr,
 	   "  -F <flag info>      0 - no flag info\n");
   fprintf (stderr,
@@ -418,7 +422,7 @@ void usage(void) {
   fprintf (stderr,
 	   "                     -1 - none (default, much faster)\n" );
   fprintf (stderr,
-	   "  -m                  monitor fvwm2 message transaction\n");
+	   "  -m                  monitor fvwm message transaction\n");
   fprintf (stderr,
 	   "  -r                  "
 	   "wait for a reply (overrides waiting time)\n");
