@@ -270,8 +270,8 @@ int main(int argc, char **argv)
     config();				/* configure events */
     execute_event(BUILTIN_STARTUP, NULL);	/* Startup event */
 
-    SendText(fd,"Nop",0);		/* what for ? */
-
+    /* tell fvwm we're running */
+    SendFinishedStartupNotification(fd);
 
     /* main loop */
 
@@ -380,7 +380,7 @@ void execute_event(short event, unsigned long *body)
 	      sprintf(buf,"%s %s", cmd_line, action_table[event]);
 	    INFO(buf);
 	    INFO("\n");
-	    SendText(fd,buf,0);		/* let fvwm2 execute the function */
+	    SendText(fd,buf,0);		/* let fvwm execute the function */
 	    last_time = now;
 	  }
 	free(buf);
