@@ -203,6 +203,7 @@ static void ct_Position(char *);
 static void ct_Read(char *);
 static void ct_Selection(char *);
 static void ct_Text(char *);
+static void ct_Title(char *);
 static void ct_UseData(char *);
 static void ct_padVText(char *);
 static void ct_WarpPointer(char *);
@@ -231,6 +232,7 @@ static struct CommandTable ct_table[] = {
   {"Position",ct_Position},
   {"Selection",ct_Selection},
   {"Text",ct_Text},
+  {"Title",ct_Title},
   {"UseData",ct_UseData},
   {"WarpPointer",ct_WarpPointer}
 };
@@ -593,6 +595,17 @@ static void ct_Text(char *cp) {
              item->header.size_x, item->header.size_y));
   AddToLine(item);
 }
+/* Set the form's title.
+   The default is the aliasname.
+   If there is no quoted string, create a blank title. */
+static void ct_Title(char *cp) {
+  /* syntax: *FFTitle "<text>" */
+  if (*cp == '\"')
+    CF.title = CopyQuotedString(++cp);
+  else
+    CF.title = "";
+  myfprintf((stderr, "Title \"%s\"\n", CF.title));
+}
 static void ct_padVText(char *cp) {
   /* syntax: *FFText "<padVText pixels>" */
   CF.padVText = atoi(cp);
@@ -869,7 +882,7 @@ static void ReadDefaults ()
     * Reading .FvwmFormDefault for every form seems slow.
     *
     * This next bit puts a command at the end of the module command
-    * queue in fvwm2 that indicates whether the file has to be read.
+    * queue in fvwm that indicates whether the file has to be read.
     *
     * Read defaults looking for "*FvwmFormDefaultRead"
     * if not there, send read,
@@ -1326,7 +1339,10 @@ static void OpenWindows ()
 			   CWColormap | CWBackPixel | CWBorderPixel, &xswa);
   XSelectInput(dpy, CF.frame,
                KeyPressMask | ExposureMask | StructureNotifyMask);
-  XStoreName(dpy, CF.frame, MyName+1);
+  if (!CF.title) {
+    CF.title = MyName+1;
+  }
+  XStoreName(dpy, CF.frame, CF.title);
   XSetWMHints(dpy, CF.frame, &wmh);
   sh.x = x, sh.y = y;
   sh.width = CF.max_width, sh.height = CF.total_height;
@@ -1697,6 +1713,7 @@ int main (int argc, char **argv)
           (M_SENDCONFIG|M_CONFIG_INFO|M_ERROR|M_STRING));
   SendInfo(Channel, mask_mesg, 0);      /* tell fvwm about our mask */
   OpenWindows();                        /* create initial window */
+  SendFinishedStartupNotification(Channel);/* tell fvwm we're running */
   MainLoop();                           /* start */
 
   return 0;                             /* */
