@@ -1,5 +1,5 @@
 /*
- * FvwmGtk - gtk menus and dialogs for fvwm2
+ * FvwmGtk - gtk menus and dialogs for fvwm
  *
  * Copyright (c) 1999 Matthias Clasen <clasen@mathematik.uni-freiburg.de>
  *
@@ -505,6 +505,10 @@ main (int argc, char **argv)
 
   gtk_input_add_full (fvwm_fd[1], GDK_INPUT_READ, read_fvwm_pipe,
                       NULL, NULL, NULL);
+
+  /* tell fvwm we're running */
+  SendFinishedStartupNotification(fvwm_fd);
+
   gtk_main ();
   return 0;
 }
