@@ -31,8 +31,9 @@ static fd_set_size_t fd_width;
 static char *IM_VERSION = "1.3";
 
 static char const rcsid[] =
-  "$Id: FvwmIconMan.c,v 1.21 1999/06/27 17:58:21 domivogt Exp $";
+  "$Id: FvwmIconMan.c,v 1.23 1999/08/19 20:27:15 domivogt Exp $";
 
+char *MyName;
 
 static RETSIGTYPE TerminateHandler(int);
 
@@ -165,7 +166,7 @@ static void main_loop (void)
 
 int main (int argc, char **argv)
 {
-  char *temp, *s;
+  char *s;
   int i;
 
 #ifdef ELECTRIC_FENCE
@@ -206,10 +207,10 @@ int main (int argc, char **argv)
   init_globals();
   init_winlists();
 
-  temp = argv[0];
+  MyName = argv[0];
   s = strrchr (argv[0], '/');
   if (s != NULL)
-    temp = s + 1;
+    MyName = s + 1;
 
   if((argc != 6) && (argc != 7)) {
     fprintf(stderr,"%s Version %s should only be executed by fvwm!\n",Module,
@@ -283,6 +284,7 @@ int main (int argc, char **argv)
                  M_ADD_WINDOW | M_DESTROY_WINDOW | M_ICON_NAME |
                  M_DEICONIFY | M_ICONIFY | M_END_WINDOWLIST |
                  M_NEW_DESK | M_NEW_PAGE | M_FOCUS_CHANGE | M_WINDOW_NAME |
+                 M_CONFIG_INFO |
 #ifdef MINI_ICONS
 		 M_MINI_ICON |
 #endif
@@ -290,6 +292,9 @@ int main (int argc, char **argv)
 
   SendInfo (Fvwm_fd, "Send_WindowList", 0);
 
+  /* tell fvwm we're running */
+  SendFinishedStartupNotification(Fvwm_fd);
+
   main_loop();
 
 #ifdef FVWM_DEBUG_MSGS
