@@ -22,7 +22,9 @@
 #include <libs/Module.h>
 
 static char const rcsid[] =
-  "$Id: fvwm.c,v 1.13 1999/07/09 17:44:31 domivogt Exp $";
+  "$Id: fvwm.c,v 1.17 1999/08/29 23:37:13 domivogt Exp $";
+
+static WinData *fvwm_focus_win = NULL;
 
 typedef struct {
   Ulong paging_enabled;
@@ -217,6 +219,19 @@ static void set_win_configuration (WinData *win, FvwmPacketBody *body)
   memcpy(&(win->flags), &(body->add_config_data.flags), sizeof(win->flags));
 }
 
+static void configure_colorsets (unsigned long *body)
+{
+  char *tline, *token;
+  int color;
+
+  tline = (char*)&(body[3]);
+  token = PeekToken(tline, &tline);
+  if (StrEquals(token, "Colorset")) {
+    color = LoadColorset(tline);
+    change_colorset(color);
+  }
+}
+
 static void configure_window (FvwmPacketBody *body)
 {
   Ulong app_id = body->add_config_data.app_id;
@@ -258,6 +273,7 @@ static void focus_change (FvwmPacketBody *body)
   }
 
   globals.focus_win = win;
+  fvwm_focus_win = win;
   ConsoleDebug (FVWM, "leaving focus_change\n");
 }
 
@@ -453,6 +469,11 @@ static void ProcessMessage (Ulong type, FvwmPacketBody *body)
   ConsoleDebug (FVWM, "FVWM Message type: %ld\n", type);
 
   switch(type) {
+  case M_CONFIG_INFO:
+    ConsoleDebug (FVWM, "DEBUG::M_CONFIG_INFO\n");
+    configure_colorsets ((unsigned long*)body);
+    break;
+
   case M_CONFIGURE_WINDOW:
     ConsoleDebug (FVWM, "DEBUG::M_CONFIGURE_WINDOW\n");
     configure_window (body);
@@ -543,6 +564,11 @@ static void ProcessMessage (Ulong type, FvwmPacketBody *body)
     globals.x = body->new_page_data.x;
     globals.y = body->new_page_data.y;
     globals.desknum = body->new_page_data.desknum;
+    if (fvwm_focus_win)
+    {
+      /* need to set the focus on a page change */
+      add_win_state (fvwm_focus_win, FOCUS_CONTEXT);
+    }
     for (i = 0; i < globals.num_managers; i++) {
       set_draw_mode (&globals.managers[i], 0);
     }
