@@ -18,9 +18,10 @@
 #include "readconfig.h"
 #include "x.h"
 #include "xmanager.h"
+#include "libs/fvwmlib.h"
 
 static char const rcsid[] =
-  "$Id: x.c,v 1.17 1999/07/02 12:42:55 hippo Exp $";
+  "$Id: x.c,v 1.27 1999/09/01 00:00:44 domivogt Exp $";
 
 #define GRAB_EVENTS (ButtonPressMask|ButtonReleaseMask|ButtonMotionMask|EnterWindowMask|LeaveWindowMask)
 
@@ -190,6 +191,7 @@ void xevent_loop (void)
   Button *b;
   static int flag = 0;
   WinManager *man;
+  Bool do_redraw = False;
 
   if (flag == 0) {
     flag = 1;
@@ -290,6 +292,57 @@ void xevent_loop (void)
       ConsoleDebug (X11, "\tborderwidth = %d\n",
 		    theEvent.xconfigure.border_width);
       ConsoleDebug (X11, "\tsendevent = %d\n", theEvent.xconfigure.send_event);
+
+      /* eat up all but last ConfigureNotify events */
+      while (XPending(theDisplay) &&
+	     XCheckMaskEvent(theDisplay, ConfigureNotify, &theEvent))
+	;
+
+      if (man->geometry.dir & GROW_FIXED)
+      {
+	man->geometry.rows =
+	  theEvent.xconfigure.height / man->geometry.boxheight;
+	if (man->geometry.rows < 1)
+	  man->geometry.rows = 1;
+	man->geometry.cols =
+	  (man->buttons.num_windows - 1) / man->geometry.rows + 1;
+	do_redraw = 1;
+      }
+      if ( man->geometry.width != theEvent.xconfigure.width ||
+           man->geometry.height != theEvent.xconfigure.height) {
+        man->geometry.width = theEvent.xconfigure.width;
+        man->geometry.height = theEvent.xconfigure.height;
+      ConsoleDebug (X11, "\tcurrent geometry: %d %d %d %d\n",
+		    man->geometry.x, man->geometry.y,
+		    man->geometry.width, man->geometry.height);
+        if (man->colorsets[DEFAULT] != -1) {
+	  if (man->pixmap[DEFAULT])
+	    XFreePixmap(theDisplay, man->pixmap[DEFAULT]);
+	  if (Colorset[man->colorsets[DEFAULT] % nColorsets].pixmap) {
+	    man->pixmap[DEFAULT] =
+	      CreateBackgroundPixmap(
+		theDisplay, man->theWindow, man->geometry.width,
+		man->geometry.height,
+		&Colorset[man->colorsets[DEFAULT] % nColorsets],
+		Pdepth, man->backContext[DEFAULT], False);
+	    XSetTile(theDisplay, man->backContext[DEFAULT],
+		     man->pixmap[DEFAULT]);
+	    XSetFillStyle(theDisplay, man->backContext[DEFAULT], FillTiled);
+	  } else {
+	    man->pixmap[DEFAULT] = None;
+	    XSetFillStyle(theDisplay, man->backContext[DEFAULT], FillSolid);
+	  }
+        }
+	do_redraw = 1;
+      }
+
+      if (do_redraw)
+      {
+	set_manager_width (man, theEvent.xconfigure.width);
+	ConsoleDebug (X11, "\tboxwidth = %d\n", man->geometry.boxwidth);
+	force_manager_redraw(man);
+      }
+
 #if 0
       set_manager_width (man, theEvent.xconfigure.width);
       ConsoleDebug (X11, "\tboxwidth = %d\n", man->geometry.boxwidth);
@@ -537,7 +590,10 @@ void X_init_manager (int man_id)
   }
 
   for ( i = 0; i < NUM_CONTEXTS; i++ ) {
-    if (man->backColorName[i]) {
+    if (man->colorsets[i] > -1) {
+      man->backcolor[i] = Colorset[man->colorsets[i] % nColorsets].bg;
+    }
+    else if (man->backColorName[i]) {
       if (!lookup_color (man->backColorName[i], &man->backcolor[i])) {
         if (!load_default_context_back (man, i)) {
 	  ConsoleMessage ("Can't load %s background color\n",
@@ -550,7 +606,10 @@ void X_init_manager (int man_id)
 		      contextDefaults[i].name);
     }
 
-    if (man->foreColorName[i]) {
+    if (man->colorsets[i] > -1) {
+      man->forecolor[i] = Colorset[man->colorsets[i] % nColorsets].fg;
+    }
+    else if (man->foreColorName[i]) {
       if (!lookup_color (man->foreColorName[i], &man->forecolor[i])) {
         if (!load_default_context_fore (man, i)) {
     	ConsoleMessage ("Can't load %s foreground color\n",
@@ -564,8 +623,15 @@ void X_init_manager (int man_id)
     }
 
     if (Pdepth > 2) {
+      if (man->colorsets[i] > -1) {
+        man->shadowcolor[i] = Colorset[man->colorsets[i] % nColorsets].shadow;
+        man->hicolor[i] = Colorset[man->colorsets[i] % nColorsets].hilite;
+      }
+      else
+      {
       man->shadowcolor[i] = GetShadow(man->backcolor[i]);
       man->hicolor[i] = GetHilite(man->backcolor[i]);
+      }
 #if 0
       /* thing about message id bg vs fg */
       if (!lookup_shadow_color (man->backcolor[i], &man->shadowcolor[i])) {
@@ -720,14 +786,31 @@ void create_manager_window (int man_id)
   sizehints.flags = man->sizehints_flags;
 
 
-  sizehints.base_width = sizehints.width = man->geometry.width;
-  sizehints.base_height = sizehints.height = man->geometry.height;
-  sizehints.min_width = 0;
+  sizehints.width = man->geometry.width;
+  sizehints.height = man->geometry.height;
+  sizehints.base_width = sizehints.min_width = 0;
+  sizehints.base_height = 0;
   sizehints.max_width = globals.screenx;
-  sizehints.min_height = man->geometry.height;
-  sizehints.max_height = man->geometry.height;
+  if (man->geometry.dir & GROW_FIXED)
+  {
+    sizehints.min_height = man->geometry.boxheight;
+    sizehints.max_height = globals.screeny;
+  }
+  else
+  {
+    sizehints.min_height = man->geometry.height;
+    sizehints.max_height = man->geometry.height;
+  }
   sizehints.win_gravity = man->gravity;
-  sizehints.flags |= PBaseSize | PMinSize | PMaxSize | PWinGravity;
+  sizehints.width_inc = 1;
+#if 0
+  sizehints.height_inc = man->geometry.boxheight;
+#else
+  /* This works much better with colour sets and when swallowed in
+   * FvwmButtons. */
+  sizehints.height_inc = 1;
+#endif
+  sizehints.flags |= PBaseSize | PMinSize | PMaxSize | PWinGravity | PResizeInc;
   sizehints.x = man->geometry.x;
   sizehints.y = man->geometry.y;
 
@@ -738,8 +821,8 @@ void create_manager_window (int man_id)
   ConsoleDebug (X11, "gravity: %d %d\n", sizehints.win_gravity, man->gravity);
 
 
-  winattr.background_pixel = man->backcolor[PLAIN_CONTEXT];
-  winattr.border_pixel = man->forecolor[PLAIN_CONTEXT];
+  winattr.background_pixel = man->backcolor[DEFAULT];
+  winattr.border_pixel = man->forecolor[DEFAULT];
   winattr.backing_store = WhenMapped;
   winattr.bit_gravity = man->gravity;
   winattr.colormap = Pcmap;
@@ -755,6 +838,7 @@ void create_manager_window (int man_id)
 				 man->geometry.width, man->geometry.height,
 				 0, Pdepth, InputOutput, Pvisual, winattrmask,
 				 &winattr);
+  XSetWMNormalHints(theDisplay, man->theWindow, &sizehints);
 #ifdef SHAPE
   XShapeSelectInput (theDisplay, man->theWindow, ShapeNotifyMask);
 #endif
@@ -804,6 +888,24 @@ void create_manager_window (int man_id)
       man->shadowContext[i] = XCreateGC (theDisplay, man->theWindow,
 						     gcmask, &gcval);
     }
+    if (man->pixmap[i])
+      XFreePixmap(theDisplay, man->pixmap[i]);
+    if (Colorset[man->colorsets[i] % nColorsets].pixmap) {
+      man->pixmap[i] = CreateBackgroundPixmap(theDisplay, man->theWindow,
+                       man->geometry.width, man->geometry.height,
+                       &Colorset[man->colorsets[i] % nColorsets],
+                       Pdepth, man->backContext[i], False);
+      XSetTile(theDisplay, man->backContext[i], man->pixmap[i]);
+      XSetFillStyle(theDisplay, man->backContext[i], FillTiled);
+      if (i == DEFAULT)
+      {
+	XSetWindowBackgroundPixmap(theDisplay, man->theWindow,
+				   man->pixmap[i]);
+      }
+    } else {
+      man->pixmap[i] = None;
+      XSetFillStyle(theDisplay, man->backContext[i], FillSolid);
+    }
   }
 
   set_window_properties (man->theWindow, man->titlename,
@@ -814,12 +916,9 @@ void create_manager_window (int man_id)
 
 static int handle_error (Display *d, XErrorEvent *ev)
 {
-  ConsoleMessage ("X Error:\n");
-  ConsoleMessage ("         error code: %d\n", ev->error_code);
-  ConsoleMessage ("         request code: %d\n", ev->request_code);
-  ConsoleMessage ("         minor code: %d\n", ev->minor_code);
-  ConsoleMessage ("Leaving a core dump now\n");
-  abort();
+  extern char *MyName;
+  /* does not return */
+  PrintXErrorAndCoredump(d, ev, MyName);
   return 0;
 }
 
@@ -832,6 +931,7 @@ void init_display (void)
   }
   XSetErrorHandler (handle_error);
   InitPictureCMap (theDisplay);
+  AllocColorset(0);
   x_fd = XConnectionNumber (theDisplay);
   theScreen = DefaultScreen (theDisplay);
   theRoot = RootWindow (theDisplay, theScreen);
@@ -849,3 +949,70 @@ void init_display (void)
   ConsoleDebug (X11, "screen width: %ld\n", globals.screenx);
   ConsoleDebug (X11, "screen height: %ld\n", globals.screeny);
 }
+
+void change_colorset(int color) {
+  WinManager *man;
+  int i,j;
+
+  for (j = 0; j < globals.num_managers; j++) {
+    man = &globals.managers[j];
+    for ( i = 0; i < NUM_CONTEXTS; i++ ) {
+      if(man->colorsets[i] == color) {
+        man->backcolor[i] = Colorset[man->colorsets[i] % nColorsets].bg;
+        man->forecolor[i] = Colorset[man->colorsets[i] % nColorsets].fg;
+        man->shadowcolor[i] = Colorset[man->colorsets[i] % nColorsets].shadow;
+        man->hicolor[i] = Colorset[man->colorsets[i] % nColorsets].hilite;
+
+        if (i == DEFAULT)
+        {
+          XSetWindowBackground(theDisplay, man->theWindow,
+                               man->backcolor[DEFAULT]);
+          XSetWindowBorder(theDisplay, man->theWindow,
+                           man->forecolor[DEFAULT]);
+        }
+	if (!man->backContext[i] || !man->hiContext[i] ||
+	    !man->flatContext[i] || !man->reliefContext[i] ||
+	    !man->shadowContext[i])
+	{
+	  /* colorset not properly defined yet, just skip it */
+	  continue;
+	}
+	XSetForeground (theDisplay, man->backContext[i], man->backcolor[i]);
+	XSetForeground (theDisplay, man->hiContext[i], man->forecolor[i]);
+	XSetBackground (theDisplay, man->flatContext[i], man->forecolor[i]);
+	XSetForeground (theDisplay, man->flatContext[i], man->backcolor[i]);
+        if (Pdepth > 2) {
+	  XSetBackground (
+	    theDisplay, man->reliefContext[i], man->backcolor[i]);
+	  XSetForeground (
+	    theDisplay, man->reliefContext[i], man->hicolor[i]);
+	  XSetBackground (
+	    theDisplay, man->shadowContext[i], man->backcolor[i]);
+	  XSetForeground (
+	    theDisplay, man->shadowContext[i], man->shadowcolor[i]);
+        }
+
+        if (man->pixmap[i])
+          XFreePixmap(theDisplay, man->pixmap[i]);
+        if (Colorset[man->colorsets[i] % nColorsets].pixmap) {
+          man->pixmap[i] = CreateBackgroundPixmap(theDisplay, man->theWindow,
+                                   man->geometry.width, man->geometry.height,
+                                   &Colorset[man->colorsets[i] % nColorsets],
+                                   Pdepth, man->backContext[i], False);
+          XSetTile(theDisplay, man->backContext[i], man->pixmap[i]);
+          XSetFillStyle(theDisplay, man->backContext[i], FillTiled);
+	  if (i == DEFAULT)
+	  {
+	    XSetWindowBackgroundPixmap(theDisplay, man->theWindow,
+				       man->pixmap[i]);
+	  }
+        } else {
+          man->pixmap[i] = None;
+          XSetFillStyle(theDisplay, man->backContext[i], FillSolid);
+        }
+
+        force_manager_redraw (man);
+      }
+    }
+  }
+}
