@@ -21,7 +21,7 @@
 #include "xmanager.h"
 
 static char const rcsid[] =
-  "$Id: xmanager.c,v 1.15 1999/07/02 12:42:55 hippo Exp $";
+  "$Id: xmanager.c,v 1.19 1999/08/26 10:22:10 hippo Exp $";
 
 #ifdef SHAPE
 #include <X11/extensions/shape.h>
@@ -199,6 +199,8 @@ static ManGeometry *figure_geometry (WinManager *man)
   if (man->geometry.dir & GROW_FIXED) {
     ret.cols = num_visible_rows (n, g->rows);
     ret.boxwidth = ret.width / ret.cols;
+    if (ret.boxwidth < 1)
+      ret.boxwidth = 1;
   }
   else {
     if (man->geometry.dir & GROW_VERT) {
@@ -258,6 +260,9 @@ static void fix_manager_size (WinManager *man, int w, int h)
   XSizeHints size;
   long mask;
 
+  if (man->geometry.dir & GROW_FIXED)
+    return;
+
   XGetWMNormalHints (theDisplay, man->theWindow, &size, &mask);
   size.min_width = w;
   size.max_width = w;
@@ -599,6 +604,8 @@ void set_manager_width (WinManager *man, int width)
 		  width / man->geometry.cols);
     man->geometry.width = width;
     man->geometry.boxwidth = width / man->geometry.cols;
+    if (man->geometry.boxwidth < 1)
+      man->geometry.boxwidth = 1;
     man->dirty_flags |= GEOMETRY_CHANGED;
   }
 }
@@ -628,8 +635,17 @@ void set_win_picture (WinData *win, Pixmap picture, Pixmap mask,
 
 void set_win_iconified (WinData *win, int iconified)
 {
+#if 0
   if (win->button && win->iconified != iconified)
     win->button->drawn_state.dirty_flags |= ICON_STATE_CHANGED;
+#else
+  /* This change has become necessary because with colorsets we don't know
+   * the background colour of the button (gradient background). Thus the button
+   * has to be redrawn completely, we can not just draw the square in the
+   * background colour. */
+  if (win->button && win->iconified != iconified)
+    win->button->drawn_state.dirty_flags |= STATE_CHANGED;
+#endif
   win->iconified = iconified;
 }
 
@@ -753,7 +769,7 @@ static void clear_empty_region (WinManager *man)
 		rects[1].x, rects[1].y, rects[1].width, rects[1].height);
 
   XFillRectangles (theDisplay, man->theWindow,
-		   man->backContext[PLAIN_CONTEXT], rects, num_rects);
+		   man->backContext[DEFAULT], rects, num_rects);
 }
 
 void set_shape (WinManager *man)
@@ -1021,6 +1037,7 @@ static void draw_3d_icon (WinManager *man, int box, ButtonGeometry *g,
 			  int iconified, int dir, Contexts contextId)
 {
   if (iconified == 0) {
+    return;
     draw_3d_square (man, g->icon_x, g->icon_y, g->icon_w, g->icon_h,
 		    man->flatContext[contextId],
 		    man->flatContext[contextId]);
@@ -1042,8 +1059,8 @@ static void draw_3d_icon (WinManager *man, int box, ButtonGeometry *g,
 
   /* this routine should only be called from draw_button() */
 static void iconify_box (WinManager *man, WinData *win, int box,
-			 ButtonGeometry *g, int iconified,
-                         Contexts contextId, int button_already_cleared)
+			 ButtonGeometry *g, int iconified, Contexts contextId,
+			 int button_already_cleared)
 {
 #ifdef MINI_ICONS
   XGCValues gcv;
@@ -1170,6 +1187,8 @@ static void draw_relief (WinManager *man, int button_state, ButtonGeometry *g,
   int state;
   state = man->buttonState[button_state];
 
+  if (state == BUTTON_FLAT)
+    return;
   if (state == BUTTON_EDGEUP || state == BUTTON_EDGEDOWN) {
     draw_3d_square (man, g->button_x, g->button_y, g->button_w, g->button_h,
 		    context1, context2);
