@@ -1,3 +1,18 @@
+/* This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ */
+
 #include "../types.h"
 
 extern char *Scrapt;
@@ -15,9 +30,15 @@ extern int x_fd;
 #define SingleClic -1
 #define DoubleClic -2
 
+#ifdef I18N_MB
+void FakeDrawString(XFontSet FONTSET, Display *dpy,GC gc,Window win,int x,int y,char *str,
+		int strl,unsigned long ForeC,unsigned long HiC,
+		unsigned long BackC,int WithRelief);
+#else
 void DrawString(Display *dpy,GC gc,Window win,int x,int y,char *str,
 		int strl,unsigned long ForeC,unsigned long HiC,
 		unsigned long BackC,int WithRelief);
+#endif
 
 char* GetMenuTitle(char *str,int id);
 
