@@ -29,6 +29,11 @@
 
 #include <X11/Xlib.h>
 #include <X11/Xproto.h>
+#include <X11/Intrinsic.h>
+
+#ifdef SHAPE
+#include <X11/extensions/shape.h>
+#endif /* SHAPE */
 
 #include "libs/fvwmlib.h"
 #include "libs/Module.h"
@@ -53,7 +58,8 @@ static void parse_message_line(char *line);
 static void main_loop(void) __attribute__((__noreturn__));
 static void parse_colorset(char *line);
 
-int main(int argc, char **argv) {
+int main(int argc, char **argv)
+{
   XSetWindowAttributes xswa;
   XGCValues xgcv;
 
@@ -79,6 +85,12 @@ int main(int argc, char **argv) {
   }
   InitPictureCMap(dpy);
 
+  /* This module allocates resouces that othe rmodules may rely on.
+   * Set the closedown mode so that the pixmaps and colors are not freed
+   * by the server if this module dies
+   */
+  XSetCloseDownMode(dpy, RetainTemporary);
+
   /* create a window to work in */
   xswa.background_pixmap = CopyFromParent;
   xswa.border_pixel = 0;
@@ -99,14 +111,24 @@ int main(int argc, char **argv) {
   /* get the initial configuration options */
   parse_config();
 
+  /* tell fvwm we're running */
+  SendFinishedStartupNotification(fd);
+
   /* garbage collect */
   alloca(0);
-  
+
+  /* just in case any previous FvwmTheme has died and left pixmaps dangling.
+   * This might be overkill but any other method must ensure that fvwm doesn't
+   * get killed (it can be the owner of the pixels in colorset 0)
+   */
+  XKillClient(dpy, AllTemporary);
+
   /* sit around waiting for something to do */
   main_loop();
 }
 
-static void main_loop(void) {
+static void main_loop(void)
+{
   FvwmPacket *packet;
 
   while (True) {
@@ -132,9 +154,17 @@ static void main_loop(void) {
 
 /* config options, the first NULL is replaced with *FvwmThemeColorset */
 /* the "Colorset" config option is what gets reflected by fvwm */
-static char *config_options[] = {"ImagePath", "ColorLimit", "Colorset", NULL, NULL};
+static char *config_options[] =
+{
+  "ImagePath",
+  "ColorLimit",
+  "Colorset",
+  NULL,
+  NULL
+};
 
-static void parse_config_line(char *line) {
+static void parse_config_line(char *line)
+{
   char *rest;
 
   switch(GetTokenIndex(line, config_options, -1, &rest)) {
@@ -151,27 +181,43 @@ static void parse_config_line(char *line) {
   case 3:
     parse_colorset(rest);
     break;
-  }    
+  }
 }
 
 /* background pixmap parsing */
-static char *pixmap_options[] = {"TiledPixmap", "Pixmap", "AspectPixmap", NULL};
+static char *pixmap_options[] =
+{
+  "TiledPixmap",
+  "Pixmap",
+  "AspectPixmap",
+  NULL
+};
+static char *shape_options[] =
+{
+  "Shape",
+  "TiledShape",
+  "AspectShape",
+  NULL
+};
+
 static char *dash = "-";
+static char *average = "Average";
 
 /* translate a colorset spec into a colorset structure */
-static void parse_colorset(char *line) {
+static void parse_colorset(char *line)
+{
   int n, ret;
+  int i;
   colorset_struct *cs;
   char *token, *fg, *bg;
   Picture *picture;
 
   /* find out which colorset and make sure it exists */
-  line = GetNextToken(line, &token);
+  token = PeekToken(line, &line);
   if (!token) {
     return;
   }
   ret = !sscanf(token, "%d", &n);
-  free(token);
   if (ret)
     return;
   cs = AllocColorset(n);
@@ -186,12 +232,12 @@ static void parse_colorset(char *line) {
     return;
   }
 
-  /* fill in the structure if color name is not "-" */
+  /* fill in the structure if color name is specified */
   if (!StrEquals(fg, dash)) {
     XFreeColors(dpy, Pcmap, &cs->fg, 1, 0);
     cs->fg = GetColor(fg);
   }
-  if (!StrEquals(bg, dash)) {
+  if (!StrEquals(bg, dash) && !StrEquals(bg, average)) {
     XFreeColors(dpy, Pcmap, &cs->bg, 3, 0);
     cs->bg = GetColor(bg);
     cs->hilite = GetHilite(cs->bg);
@@ -199,35 +245,114 @@ static void parse_colorset(char *line) {
   }
 
   /* look for a pixmap specifier, if not "-" remove the existing one */
-  GetNextToken(line, &token);
+  token = PeekToken(line, &line);
   if (token) {
     ret = StrEquals(token, dash);
-    free(token);
   }
   if (!ret) {
     XFreePixmap(dpy, cs->pixmap);
+    XFreePixmap(dpy, cs->mask);
+    XFreePixmap(dpy, cs->shape_mask);
     cs->pixmap = None;
+    cs->mask = None;
+    cs->shape_mask = None;
+  }
+
+  i = GetTokenIndex(token, shape_options, 0, NULL);
+  if (i != -1)
+  {
+    /* read filename */
+    token = PeekToken(line, &line);
+#ifdef SHAPE
+    /* set the flags */
+    cs->shape_tile = 0;
+    cs->shape_keep_aspect = 0;
+    if (i == 1)
+      cs->shape_tile = 1;
+    else if (i == 2)
+      cs->shape_keep_aspect = 1;
+
+    /* try to load the shape mask */
+    if (token && !ret)
+    {
+      /* load the shape mask */
+      picture = GetPicture(dpy, win, NULL, token, color_limit);
+      if (!picture)
+	fprintf(stderr, "%s: can't load picture %s\n", name, token);
+      else if (picture->depth != 1 && picture->mask == None)
+      {
+	fprintf(stderr, "%s: shape pixmap must be of depth 1\n", name);
+	DestroyPicture(dpy, picture);
+      }
+      else
+      {
+	Pixmap mask;
+
+	/* okay, we have what we want */
+	if (picture->mask != None)
+	  mask = picture->mask;
+	else
+	  mask = picture->picture;
+	/* Need to set width and height here in case there was no other pixmap
+	 * specified! Will be overwritten if we have a pixmat or gradient on
+	 * the same line. */
+	cs->width = picture->width;
+	cs->height = picture->height;
+
+	if (mask != None)
+	{
+	  cs->shape_mask = XCreatePixmap(
+	    dpy, mask, picture->width, picture->height, 1);
+	  if (cs->shape_mask != None)
+	  {
+	    XGCValues xgcv;
+	    static GC shape_gc = None;
+
+	    if (shape_gc == None)
+	    {
+	      xgcv.foreground = 1;
+	      xgcv.background = 0;
+	      /* create a gc for 1 bit depth */
+	      shape_gc = XCreateGC(
+		dpy, picture->mask, GCForeground|GCBackground, &xgcv);
+	    }
+	    XCopyPlane(dpy, mask, cs->shape_mask, shape_gc, 0, 0,
+		       picture->width, picture->height, 0, 0, 1);
+	  }
+	}
+      }
+      if (picture)
+      {
+	DestroyPicture(dpy, picture);
+	picture = None;
+      }
+    }
+#else
+    cs->shape_mask = None;
+#endif /* SHAPE */
+    /* skip filename */
+    token = PeekToken(line, &line);
   }
 
   /* if one was specified try to load it */
-  if (token && !ret) {
-    int type = GetTokenIndex(line, pixmap_options, -1, &line);
-    char *end;
+  if (token && !ret)
+  {
+    int type = GetTokenIndex(token, pixmap_options, 0, NULL);
     unsigned int w, h;
 
-    switch(type) {
+    switch(type)
+    {
     case 0:
     case 1:
     case 2:
-      /* all three of these are pixmaps, the differ in size bits */
-      GetNextToken(line, &token);
+      /* all three of these are pixmaps, they differ in size bits */
+      token = PeekToken(line, NULL);
       if (!token)
 	break;
       /* load the file using the color reduction routines in Picture.c */
       picture = GetPicture(dpy, win, NULL, token, color_limit);
       if (!picture)
 	fprintf(stderr, "%s: can't load picture %s\n", name, token);
-      free (token);
       if (!picture)
 	break;
       /* don't try to be smart with bitmaps */
@@ -242,38 +367,107 @@ static void parse_colorset(char *line) {
       cs->width = picture->width;
       cs->height = picture->height;
       cs->pixmap = XCreatePixmap(dpy, win, cs->width, cs->height, Pdepth);
+      if (picture->mask != None)
+      {
+	/* default to background colour where pixmap is transparent */
+	XSetForeground(dpy, gc, cs->bg);
+	XFillRectangle(dpy, cs->pixmap, gc, 0, 0, cs->width, cs->height);
+	XSetClipMask(dpy, gc, picture->mask);
+      }
       XCopyArea(dpy, picture->picture, cs->pixmap, gc, 0, 0, cs->width,
 		cs->height, 0, 0);
+      if (picture->mask != None)
+      {
+	XGCValues xgcv;
+	static GC mask_gc = None;
+
+	/* first restore the gc we modified earlier */
+	XSetClipMask(dpy, gc, None);
+	/* make sure we have a gc */
+	if (mask_gc == None)
+	{
+	  /* create a gc for 1 bit depth */
+	  mask_gc = XCreateGC(dpy, picture->mask, 0, &xgcv);
+	}
+	cs->mask = XCreatePixmap(
+	  dpy, picture->mask, cs->width, cs->height, 1);
+	XCopyArea(dpy, picture->mask, cs->mask, mask_gc, 0, 0, cs->width,
+		  cs->height, 0, 0);
+      }
       DestroyPicture(dpy, picture);
       cs->keep_aspect = (type == 2);
       cs->stretch_x = cs->stretch_y = (type != 0);
       break;
     default:
       /* test for ?Gradient */
-      end = GetNextToken(line, &token);
       if (!token)
 	break;
       type = toupper(token[0]);
       if (token[1])
         ret = StrEquals(&token[1], "Gradient");
-      free(token);
       if (!ret) {
-	fprintf(stderr, "%s: bad colorset pixmap specifier %s\n", name, line);
+	fprintf(stderr, "%s: bad colorset pixmap specifier %s %s\n", name,
+		token, line);
 	break;
       }
+      if (!IsGradientTypeSupported(type))
+	break;
+
       /* create a pixmap of the gradient type */
-      cs->pixmap = CreateGradientPixmap(dpy, win, gc, type, end, &w, &h);
+      cs->pixmap =
+	CreateGradientPixmapFromString(dpy, win, gc, type, line, &w, &h);
       cs->width = w;
       cs->height = h;
       cs->keep_aspect = False;
-      cs->stretch_x = !(type == 'V');
-      cs->stretch_y = !(type == 'H');
+      cs->stretch_x = !(type == V_GRADIENT);
+      cs->stretch_y = !(type == H_GRADIENT);
     }
   }
 
+  /* calculate average background color */
+  if (StrEquals(bg, average) && cs->pixmap) {
+    XColor color;
+    XColor *colors;
+    XImage *image;
+    unsigned int i, j, k = 0;
+    unsigned long red = 0, blue = 0, green = 0;
+
+    /* create an array to store all the pixmap colors in */
+    colors = (XColor *)safemalloc(cs->width * cs->height * sizeof(XColor));
+    /* get the pixmap into an image */
+    image = XGetImage(dpy, cs->pixmap, 0, 0, cs->width, cs->height, AllPlanes,
+		      ZPixmap);
+    /* get each pixel */
+    for (i = 0; i < cs->width; i++)
+      for (j = 0; j < cs->height; j++)
+	colors[k++].pixel = XGetPixel(image, i, j);
+    XDestroyImage(image);
+    /* look them all up, XQueryColors() can't handle more than 256 */
+    for (i = 0; i < k; i += 256)
+      XQueryColors(dpy, Pcmap, &colors[i], min(k - i, 256));
+    /* calculate average, ignore overflow: .red is a short, red is a long */
+    for (i = 0; i < k; i++) {
+      red += colors[i].red;
+      green += colors[i].green;
+      blue += colors[i].blue;
+    }
+    free(colors);
+    /* get it */
+    XFreeColors(dpy, Pcmap, &cs->bg, 3, 0);
+    k = cs->width * cs->height;
+    color.red = red / k;
+    color.green = green / k;
+    color.blue = blue / k;
+    color.flags = DoRed | DoGreen | DoBlue;
+    XAllocColor(dpy, Pcmap, &color);
+    cs->bg = color.pixel;
+    cs->hilite = GetHilite(cs->bg);
+    cs->shadow = GetShadow(cs->bg);
+  }
+
   /* make sure the server has this to avoid races */
   XSync(dpy, False);
-  
+
   /* inform fvwm of the change */
   SendText(fd, DumpColorset(n), 0);
 }
@@ -288,7 +482,7 @@ static void parse_message_line(char *line) {
   case 0:
     parse_colorset(rest);
     break;
-  }    
+  }
 }
 
 static void parse_config(void) {
@@ -300,7 +494,7 @@ static void parse_config(void) {
 
   /* set a filter on the config lines sent */
   InitGetConfigLine(fd, config_options[3]);
-  
+
   /* tell fvwm what we want to receive */
   SetMessageMask(fd, M_CONFIG_INFO | M_END_CONFIG_INFO
 		 | M_SENDCONFIG | M_STRING);
@@ -311,9 +505,8 @@ static void parse_config(void) {
     parse_config_line(line);
 }
 
-static int error_handler(Display *d, XErrorEvent *e) {
-  char msg[256];
-  
+static int error_handler(Display *d, XErrorEvent *e)
+{
   /* Attempting to free colors or pixmaps that were not allocated by this
    * module or were never allocated at all does not cause problems */
   if (((X_FreeColors == e->request_code) && (BadAccess == e->error_code))
@@ -321,11 +514,8 @@ static int error_handler(Display *d, XErrorEvent *e) {
     return 0;
 
   /* other errors cause diagnostic output and stop execution */
-  XGetErrorText(d, e->error_code, msg, sizeof(msg));
-  fprintf(stderr, "%s: X error: %s\n", name, msg);
-  fprintf(stderr, "Major opcode of failed request: %d \n", e->request_code);
-  fprintf(stderr, "Resource id of failed request: 0x%lx \n", e->resourceid);
-  exit(0);
+  PrintXErrorAndCoredump(d, e, name);
+  return 0;
 }
 
 static void set_signals(void) {
