@@ -259,6 +259,10 @@ int main(int argc, char **argv)
 
   /* Recieve all messages from Fvwm */
   atexit(ShutMeDown);
+
+  /* tell fvwm we're running */
+  SendFinishedStartupNotification(Fvwm_fd);
+
   MainEventLoop();
 #ifdef FVWM_DEBUG_MSGS
   if ( debug_term_signal )
@@ -675,10 +679,10 @@ ParseConfigLine(char *tline)
       colorset[2] = colorset[3] = atoi(&tline[Clength + 13]);
     else if (strncasecmp(tline, "Colorset", 8) == 0) {
       int cset = LoadColorset(&tline[8]);
-      
+
       if (WindowIsUp && (cset >= 0)) {
 	int i;
-	
+
 	for (i = 0; i != MAX_COLOUR_SETS; i++) {
 	  if (colorset[i] == cset) {
 	    AdjustWindow(True);
@@ -796,41 +800,13 @@ void LoopOnEvents(void)
 }
 
 
-/******************************************************************************
-  find_frame_window - looks for ancestor that is a child of the root
-  Cribbed from FvwmIconMan/x.c - maybe should be in a library
-  Returns the root-child and fills in off_x, off_y to give offset
-******************************************************************************/
-Window find_frame_window (Window win, int *off_x, int *off_y)
-{
-  Window root, parent, *junkw;
-  unsigned int junki;
-  XWindowAttributes attr;
-
-  while (1) {
-    XQueryTree (dpy, win, &root, &parent, &junkw, &junki);
-    if (junkw)
-      XFree (junkw);
-    if (parent == root)
-      break;
-    XGetWindowAttributes (dpy, win, &attr);
-    *off_x += attr.x + attr.border_width;
-    *off_y += attr.y + attr.border_width;
-    win = parent;
-  }
-
-  return win;
-}
-
 /******************************************************************************
   AdjustWindow - Resize the window according to maxwidth by number of buttons
 ******************************************************************************/
 void AdjustWindow(Bool force)
 {
-  int new_width=0,new_height=0,tw,i,total,off_x,off_y;
+  int new_width=0,new_height=0,tw,i,total;
   char *temp;
-  Window frame;
-  XWindowAttributes win_attr, frame_attr;
 
   total = ItemCountD(&windows );
   if (!total)
@@ -860,11 +836,11 @@ void AdjustWindow(Bool force)
   new_width=max(new_width, MinWidth);
   new_width=min(new_width, MaxWidth);
   new_height=(total * (fontheight + 3 + 2 * ReliefWidth));
-  if (force || (WindowIsUp && (new_height != win_height 
+  if (force || (WindowIsUp && (new_height != win_height
 			       || new_width != win_width))) {
     for (i = 0; i != MAX_COLOUR_SETS; i++) {
       int cset = colorset[i];
-      
+
       if (cset >= 0) {
         cset = cset % nColorsets;
 	fore[i] = Colorset[cset].fg;
@@ -879,7 +855,7 @@ void AdjustWindow(Bool force)
 	  pixmap[i] = CreateBackgroundPixmap(dpy, win, new_width,
 					     fontheight + 3 + 2 * ReliefWidth,
 					     &Colorset[cset], Pdepth,
-					     background[i]);
+					     background[i], False);
 	  XSetTile(dpy, background[i], pixmap[i]);
 	  XSetFillStyle(dpy, background[i], FillTiled);
 	} else {
@@ -893,18 +869,14 @@ void AdjustWindow(Bool force)
   {
     if (Anchor)
     {
-      off_x = off_y = 0;
-      MyXGrabServer(dpy);
-      frame = find_frame_window(win, &off_x, &off_y);
-      XGetWindowAttributes(dpy, frame, &frame_attr);
-      XGetWindowAttributes(dpy, win, &win_attr);
-      win_x = frame_attr.x + frame_attr.border_width + off_x;
-      win_y = frame_attr.y + frame_attr.border_width + off_y;
+      Window child;
 
+      MyXGrabServer(dpy);
+      XTranslateCoordinates(dpy, win, Root, 0, 0, &win_x, &win_y, &child);
       if (win_grav == SouthEastGravity || win_grav == NorthEastGravity)
-        win_x += win_attr.width - new_width;
+        win_x += win_width - new_width;
       if (win_grav == SouthEastGravity || win_grav == SouthWestGravity)
-        win_y += win_attr.height - new_height;
+        win_y += win_height - new_height;
 
       XMoveResizeWindow(dpy, win, win_x, win_y, new_width, new_height);
       MyXUngrabServer(dpy);
@@ -1244,12 +1216,7 @@ PropMwmHints prop;
 ************************************************************************/
 int ErrorHandler(Display *d, XErrorEvent *event)
 {
-    char errmsg[256];
-
-    XGetErrorText(d, event->error_code, errmsg, sizeof(errmsg));
-    ConsoleMessage("%s failed request: %s\n", Module, errmsg);
-    ConsoleMessage("Major opcode: 0x%x, resource id: 0x%lx\n",
-		   event->request_code, (unsigned long)event->resourceid);
+    PrintXErrorAndCoredump(d, event, Module);
     return 0;
 }
 
